// Code generated by 'yaegi extract syscall'. DO NOT EDIT.

//go:build go1.22
// +build go1.22

package syscall

import (
	"go/constant"
	"go/token"
	"reflect"
	"syscall"
)

func init() {
	Symbols["syscall/syscall"] = map[string]reflect.Value{
		// function, constant and variable definitions
		"AF_APPLETALK":                  reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"AF_BYPASS":                     reflect.ValueOf(constant.MakeFromLiteral("25", token.INT, 0)),
		"AF_CCITT":                      reflect.ValueOf(constant.MakeFromLiteral("10", token.INT, 0)),
		"AF_CHAOS":                      reflect.ValueOf(constant.MakeFromLiteral("5", token.INT, 0)),
		"AF_DATAKIT":                    reflect.ValueOf(constant.MakeFromLiteral("9", token.INT, 0)),
		"AF_DECnet":                     reflect.ValueOf(constant.MakeFromLiteral("12", token.INT, 0)),
		"AF_DLI":                        reflect.ValueOf(constant.MakeFromLiteral("13", token.INT, 0)),
		"AF_ECMA":                       reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"AF_HYLINK":                     reflect.ValueOf(constant.MakeFromLiteral("15", token.INT, 0)),
		"AF_IMPLINK":                    reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"AF_INET":                       reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"AF_INET6":                      reflect.ValueOf(constant.MakeFromLiteral("24", token.INT, 0)),
		"AF_INTF":                       reflect.ValueOf(constant.MakeFromLiteral("20", token.INT, 0)),
		"AF_ISO":                        reflect.ValueOf(constant.MakeFromLiteral("7", token.INT, 0)),
		"AF_LAT":                        reflect.ValueOf(constant.MakeFromLiteral("14", token.INT, 0)),
		"AF_LINK":                       reflect.ValueOf(constant.MakeFromLiteral("18", token.INT, 0)),
		"AF_LOCAL":                      reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"AF_MAX":                        reflect.ValueOf(constant.MakeFromLiteral("30", token.INT, 0)),
		"AF_NDD":                        reflect.ValueOf(constant.MakeFromLiteral("23", token.INT, 0)),
		"AF_NETWARE":                    reflect.ValueOf(constant.MakeFromLiteral("22", token.INT, 0)),
		"AF_NS":                         reflect.ValueOf(constant.MakeFromLiteral("6", token.INT, 0)),
		"AF_OSI":                        reflect.ValueOf(constant.MakeFromLiteral("7", token.INT, 0)),
		"AF_PUP":                        reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"AF_RIF":                        reflect.ValueOf(constant.MakeFromLiteral("21", token.INT, 0)),
		"AF_ROUTE":                      reflect.ValueOf(constant.MakeFromLiteral("17", token.INT, 0)),
		"AF_SNA":                        reflect.ValueOf(constant.MakeFromLiteral("11", token.INT, 0)),
		"AF_UNIX":                       reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"AF_UNSPEC":                     reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"ARPHRD_802_3":                  reflect.ValueOf(constant.MakeFromLiteral("6", token.INT, 0)),
		"ARPHRD_802_5":                  reflect.ValueOf(constant.MakeFromLiteral("6", token.INT, 0)),
		"ARPHRD_ETHER":                  reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"ARPHRD_FDDI":                   reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"Accept":                        reflect.ValueOf(syscall.Accept),
		"Access":                        reflect.ValueOf(syscall.Access),
		"Acct":                          reflect.ValueOf(syscall.Acct),
		"B0":                            reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"B110":                          reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"B1200":                         reflect.ValueOf(constant.MakeFromLiteral("9", token.INT, 0)),
		"B134":                          reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"B150":                          reflect.ValueOf(constant.MakeFromLiteral("5", token.INT, 0)),
		"B1800":                         reflect.ValueOf(constant.MakeFromLiteral("10", token.INT, 0)),
		"B19200":                        reflect.ValueOf(constant.MakeFromLiteral("14", token.INT, 0)),
		"B200":                          reflect.ValueOf(constant.MakeFromLiteral("6", token.INT, 0)),
		"B2400":                         reflect.ValueOf(constant.MakeFromLiteral("11", token.INT, 0)),
		"B300":                          reflect.ValueOf(constant.MakeFromLiteral("7", token.INT, 0)),
		"B38400":                        reflect.ValueOf(constant.MakeFromLiteral("15", token.INT, 0)),
		"B4800":                         reflect.ValueOf(constant.MakeFromLiteral("12", token.INT, 0)),
		"B50":                           reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"B600":                          reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"B75":                           reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"B9600":                         reflect.ValueOf(constant.MakeFromLiteral("13", token.INT, 0)),
		"BRKINT":                        reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"Bind":                          reflect.ValueOf(syscall.Bind),
		"BytePtrFromString":             reflect.ValueOf(syscall.BytePtrFromString),
		"ByteSliceFromString":           reflect.ValueOf(syscall.ByteSliceFromString),
		"CFLUSH":                        reflect.ValueOf(constant.MakeFromLiteral("15", token.INT, 0)),
		"CLOCAL":                        reflect.ValueOf(constant.MakeFromLiteral("2048", token.INT, 0)),
		"CREAD":                         reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"CS5":                           reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"CS6":                           reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"CS7":                           reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"CS8":                           reflect.ValueOf(constant.MakeFromLiteral("48", token.INT, 0)),
		"CSIOCGIFCONF":                  reflect.ValueOf(constant.MakeFromLiteral("-1072666332", token.INT, 0)),
		"CSIZE":                         reflect.ValueOf(constant.MakeFromLiteral("48", token.INT, 0)),
		"CSMAP_DIR":                     reflect.ValueOf(constant.MakeFromLiteral("\"/usr/lib/nls/csmap/\"", token.STRING, 0)),
		"CSTART":                        reflect.ValueOf(constant.MakeFromLiteral("17", token.INT, 0)),
		"CSTOP":                         reflect.ValueOf(constant.MakeFromLiteral("19", token.INT, 0)),
		"CSTOPB":                        reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"CSUSP":                         reflect.ValueOf(constant.MakeFromLiteral("26", token.INT, 0)),
		"Chdir":                         reflect.ValueOf(syscall.Chdir),
		"Chmod":                         reflect.ValueOf(syscall.Chmod),
		"Chown":                         reflect.ValueOf(syscall.Chown),
		"Chroot":                        reflect.ValueOf(syscall.Chroot),
		"Clearenv":                      reflect.ValueOf(syscall.Clearenv),
		"Close":                         reflect.ValueOf(syscall.Close),
		"CloseOnExec":                   reflect.ValueOf(syscall.CloseOnExec),
		"CmsgLen":                       reflect.ValueOf(syscall.CmsgLen),
		"CmsgSpace":                     reflect.ValueOf(syscall.CmsgSpace),
		"Connect":                       reflect.ValueOf(syscall.Connect),
		"Dup":                           reflect.ValueOf(syscall.Dup),
		"Dup2":                          reflect.ValueOf(syscall.Dup2),
		"E2BIG":                         reflect.ValueOf(syscall.E2BIG),
		"EACCES":                        reflect.ValueOf(syscall.EACCES),
		"EADDRINUSE":                    reflect.ValueOf(syscall.EADDRINUSE),
		"EADDRNOTAVAIL":                 reflect.ValueOf(syscall.EADDRNOTAVAIL),
		"EAFNOSUPPORT":                  reflect.ValueOf(syscall.EAFNOSUPPORT),
		"EAGAIN":                        reflect.ValueOf(syscall.EAGAIN),
		"EALREADY":                      reflect.ValueOf(syscall.EALREADY),
		"EBADF":                         reflect.ValueOf(syscall.EBADF),
		"EBADMSG":                       reflect.ValueOf(syscall.EBADMSG),
		"EBUSY":                         reflect.ValueOf(syscall.EBUSY),
		"ECANCELED":                     reflect.ValueOf(syscall.ECANCELED),
		"ECHILD":                        reflect.ValueOf(syscall.ECHILD),
		"ECHO":                          reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"ECHOCTL":                       reflect.ValueOf(constant.MakeFromLiteral("131072", token.INT, 0)),
		"ECHOE":                         reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"ECHOK":                         reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"ECHOKE":                        reflect.ValueOf(constant.MakeFromLiteral("524288", token.INT, 0)),
		"ECHONL":                        reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"ECHOPRT":                       reflect.ValueOf(constant.MakeFromLiteral("262144", token.INT, 0)),
		"ECHRNG":                        reflect.ValueOf(syscall.ECHRNG),
		"ECH_ICMPID":                    reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"ECLONEME":                      reflect.ValueOf(syscall.ECLONEME),
		"ECONNABORTED":                  reflect.ValueOf(syscall.ECONNABORTED),
		"ECONNREFUSED":                  reflect.ValueOf(syscall.ECONNREFUSED),
		"ECONNRESET":                    reflect.ValueOf(syscall.ECONNRESET),
		"ECORRUPT":                      reflect.ValueOf(syscall.ECORRUPT),
		"EDEADLK":                       reflect.ValueOf(syscall.EDEADLK),
		"EDESTADDREQ":                   reflect.ValueOf(syscall.EDESTADDREQ),
		"EDESTADDRREQ":                  reflect.ValueOf(syscall.EDESTADDRREQ),
		"EDIST":                         reflect.ValueOf(syscall.EDIST),
		"EDOM":                          reflect.ValueOf(syscall.EDOM),
		"EDQUOT":                        reflect.ValueOf(syscall.EDQUOT),
		"EEXIST":                        reflect.ValueOf(syscall.EEXIST),
		"EFAULT":                        reflect.ValueOf(syscall.EFAULT),
		"EFBIG":                         reflect.ValueOf(syscall.EFBIG),
		"EFORMAT":                       reflect.ValueOf(syscall.EFORMAT),
		"EHOSTDOWN":                     reflect.ValueOf(syscall.EHOSTDOWN),
		"EHOSTUNREACH":                  reflect.ValueOf(syscall.EHOSTUNREACH),
		"EIDRM":                         reflect.ValueOf(syscall.EIDRM),
		"EILSEQ":                        reflect.ValueOf(syscall.EILSEQ),
		"EINPROGRESS":                   reflect.ValueOf(syscall.EINPROGRESS),
		"EINTR":                         reflect.ValueOf(syscall.EINTR),
		"EINVAL":                        reflect.ValueOf(syscall.EINVAL),
		"EIO":                           reflect.ValueOf(syscall.EIO),
		"EISCONN":                       reflect.ValueOf(syscall.EISCONN),
		"EISDIR":                        reflect.ValueOf(syscall.EISDIR),
		"EL2HLT":                        reflect.ValueOf(syscall.EL2HLT),
		"EL2NSYNC":                      reflect.ValueOf(syscall.EL2NSYNC),
		"EL3HLT":                        reflect.ValueOf(syscall.EL3HLT),
		"EL3RST":                        reflect.ValueOf(syscall.EL3RST),
		"ELNRNG":                        reflect.ValueOf(syscall.ELNRNG),
		"ELOOP":                         reflect.ValueOf(syscall.ELOOP),
		"EMEDIA":                        reflect.ValueOf(syscall.EMEDIA),
		"EMFILE":                        reflect.ValueOf(syscall.EMFILE),
		"EMLINK":                        reflect.ValueOf(syscall.EMLINK),
		"EMSGSIZE":                      reflect.ValueOf(syscall.EMSGSIZE),
		"EMULTIHOP":                     reflect.ValueOf(syscall.EMULTIHOP),
		"ENAMETOOLONG":                  reflect.ValueOf(syscall.ENAMETOOLONG),
		"ENETDOWN":                      reflect.ValueOf(syscall.ENETDOWN),
		"ENETRESET":                     reflect.ValueOf(syscall.ENETRESET),
		"ENETUNREACH":                   reflect.ValueOf(syscall.ENETUNREACH),
		"ENFILE":                        reflect.ValueOf(syscall.ENFILE),
		"ENOATTR":                       reflect.ValueOf(syscall.ENOATTR),
		"ENOBUFS":                       reflect.ValueOf(syscall.ENOBUFS),
		"ENOCONNECT":                    reflect.ValueOf(syscall.ENOCONNECT),
		"ENOCSI":                        reflect.ValueOf(syscall.ENOCSI),
		"ENODATA":                       reflect.ValueOf(syscall.ENODATA),
		"ENODEV":                        reflect.ValueOf(syscall.ENODEV),
		"ENOENT":                        reflect.ValueOf(syscall.ENOENT),
		"ENOEXEC":                       reflect.ValueOf(syscall.ENOEXEC),
		"ENOLCK":                        reflect.ValueOf(syscall.ENOLCK),
		"ENOLINK":                       reflect.ValueOf(syscall.ENOLINK),
		"ENOMEM":                        reflect.ValueOf(syscall.ENOMEM),
		"ENOMSG":                        reflect.ValueOf(syscall.ENOMSG),
		"ENOPROTOOPT":                   reflect.ValueOf(syscall.ENOPROTOOPT),
		"ENOSPC":                        reflect.ValueOf(syscall.ENOSPC),
		"ENOSR":                         reflect.ValueOf(syscall.ENOSR),
		"ENOSTR":                        reflect.ValueOf(syscall.ENOSTR),
		"ENOSYS":                        reflect.ValueOf(syscall.ENOSYS),
		"ENOTBLK":                       reflect.ValueOf(syscall.ENOTBLK),
		"ENOTCONN":                      reflect.ValueOf(syscall.ENOTCONN),
		"ENOTDIR":                       reflect.ValueOf(syscall.ENOTDIR),
		"ENOTEMPTY":                     reflect.ValueOf(syscall.ENOTEMPTY),
		"ENOTREADY":                     reflect.ValueOf(syscall.ENOTREADY),
		"ENOTRECOVERABLE":               reflect.ValueOf(syscall.ENOTRECOVERABLE),
		"ENOTRUST":                      reflect.ValueOf(syscall.ENOTRUST),
		"ENOTSOCK":                      reflect.ValueOf(syscall.ENOTSOCK),
		"ENOTSUP":                       reflect.ValueOf(syscall.ENOTSUP),
		"ENOTTY":                        reflect.ValueOf(syscall.ENOTTY),
		"ENXIO":                         reflect.ValueOf(syscall.ENXIO),
		"EOPNOTSUPP":                    reflect.ValueOf(syscall.EOPNOTSUPP),
		"EOVERFLOW":                     reflect.ValueOf(syscall.EOVERFLOW),
		"EOWNERDEAD":                    reflect.ValueOf(syscall.EOWNERDEAD),
		"EPERM":                         reflect.ValueOf(syscall.EPERM),
		"EPFNOSUPPORT":                  reflect.ValueOf(syscall.EPFNOSUPPORT),
		"EPIPE":                         reflect.ValueOf(syscall.EPIPE),
		"EPROCLIM":                      reflect.ValueOf(syscall.EPROCLIM),
		"EPROTO":                        reflect.ValueOf(syscall.EPROTO),
		"EPROTONOSUPPORT":               reflect.ValueOf(syscall.EPROTONOSUPPORT),
		"EPROTOTYPE":                    reflect.ValueOf(syscall.EPROTOTYPE),
		"ERANGE":                        reflect.ValueOf(syscall.ERANGE),
		"EREMOTE":                       reflect.ValueOf(syscall.EREMOTE),
		"ERESTART":                      reflect.ValueOf(syscall.ERESTART),
		"EROFS":                         reflect.ValueOf(syscall.EROFS),
		"ESAD":                          reflect.ValueOf(syscall.ESAD),
		"ESHUTDOWN":                     reflect.ValueOf(syscall.ESHUTDOWN),
		"ESOCKTNOSUPPORT":               reflect.ValueOf(syscall.ESOCKTNOSUPPORT),
		"ESOFT":                         reflect.ValueOf(syscall.ESOFT),
		"ESPIPE":                        reflect.ValueOf(syscall.ESPIPE),
		"ESRCH":                         reflect.ValueOf(syscall.ESRCH),
		"ESTALE":                        reflect.ValueOf(syscall.ESTALE),
		"ESYSERROR":                     reflect.ValueOf(syscall.ESYSERROR),
		"ETHERNET_CSMACD":               reflect.ValueOf(constant.MakeFromLiteral("6", token.INT, 0)),
		"ETIME":                         reflect.ValueOf(syscall.ETIME),
		"ETIMEDOUT":                     reflect.ValueOf(syscall.ETIMEDOUT),
		"ETOOMANYREFS":                  reflect.ValueOf(syscall.ETOOMANYREFS),
		"ETXTBSY":                       reflect.ValueOf(syscall.ETXTBSY),
		"EUNATCH":                       reflect.ValueOf(syscall.EUNATCH),
		"EUSERS":                        reflect.ValueOf(syscall.EUSERS),
		"EVENP":                         reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"EWOULDBLOCK":                   reflect.ValueOf(syscall.EWOULDBLOCK),
		"EWRPROTECT":                    reflect.ValueOf(syscall.EWRPROTECT),
		"EXCONTINUE":                    reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"EXDEV":                         reflect.ValueOf(syscall.EXDEV),
		"EXDLOK":                        reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"EXIO":                          reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"EXPGIO":                        reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"EXRESUME":                      reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"EXRETURN":                      reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"EXSIG":                         reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"EXTA":                          reflect.ValueOf(constant.MakeFromLiteral("14", token.INT, 0)),
		"EXTB":                          reflect.ValueOf(constant.MakeFromLiteral("15", token.INT, 0)),
		"EXTRAP":                        reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"EYEC_RTENTRYA":                 reflect.ValueOf(constant.MakeFromLiteral("2698347105741992513", token.INT, 0)),
		"EYEC_RTENTRYF":                 reflect.ValueOf(constant.MakeFromLiteral("2698347105741992518", token.INT, 0)),
		"E_ACC":                         reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"Environ":                       reflect.ValueOf(syscall.Environ),
		"FD_CLOEXEC":                    reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"FD_SETSIZE":                    reflect.ValueOf(constant.MakeFromLiteral("65534", token.INT, 0)),
		"FLUSHBAND":                     reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"FLUSHLOW":                      reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"FLUSHO":                        reflect.ValueOf(constant.MakeFromLiteral("1048576", token.INT, 0)),
		"FLUSHR":                        reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"FLUSHRW":                       reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"FLUSHW":                        reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"F_CLOSEM":                      reflect.ValueOf(constant.MakeFromLiteral("10", token.INT, 0)),
		"F_DUP2FD":                      reflect.ValueOf(constant.MakeFromLiteral("14", token.INT, 0)),
		"F_DUPFD":                       reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"F_DUPFD_CLOEXEC":               reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"F_GETFD":                       reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"F_GETFL":                       reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"F_GETLK":                       reflect.ValueOf(constant.MakeFromLiteral("11", token.INT, 0)),
		"F_GETLK64":                     reflect.ValueOf(constant.MakeFromLiteral("11", token.INT, 0)),
		"F_GETOWN":                      reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"F_LOCK":                        reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"F_OK":                          reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"F_RDLCK":                       reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"F_SETFD":                       reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"F_SETFL":                       reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"F_SETLK":                       reflect.ValueOf(constant.MakeFromLiteral("12", token.INT, 0)),
		"F_SETLK64":                     reflect.ValueOf(constant.MakeFromLiteral("12", token.INT, 0)),
		"F_SETLKW":                      reflect.ValueOf(constant.MakeFromLiteral("13", token.INT, 0)),
		"F_SETLKW64":                    reflect.ValueOf(constant.MakeFromLiteral("13", token.INT, 0)),
		"F_SETOWN":                      reflect.ValueOf(constant.MakeFromLiteral("9", token.INT, 0)),
		"F_TEST":                        reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"F_TLOCK":                       reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"F_TSTLK":                       reflect.ValueOf(constant.MakeFromLiteral("15", token.INT, 0)),
		"F_ULOCK":                       reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"F_UNLCK":                       reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"F_WRLCK":                       reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"Faccessat":                     reflect.ValueOf(syscall.Faccessat),
		"Fchdir":                        reflect.ValueOf(syscall.Fchdir),
		"Fchmod":                        reflect.ValueOf(syscall.Fchmod),
		"Fchmodat":                      reflect.ValueOf(syscall.Fchmodat),
		"Fchown":                        reflect.ValueOf(syscall.Fchown),
		"Fchownat":                      reflect.ValueOf(syscall.Fchownat),
		"FcntlFlock":                    reflect.ValueOf(syscall.FcntlFlock),
		"ForkLock":                      reflect.ValueOf(&syscall.ForkLock).Elem(),
		"Fpathconf":                     reflect.ValueOf(syscall.Fpathconf),
		"Fstat":                         reflect.ValueOf(syscall.Fstat),
		"Fstatfs":                       reflect.ValueOf(syscall.Fstatfs),
		"Fsync":                         reflect.ValueOf(syscall.Fsync),
		"Ftruncate":                     reflect.ValueOf(syscall.Ftruncate),
		"Getcwd":                        reflect.ValueOf(syscall.Getcwd),
		"Getegid":                       reflect.ValueOf(syscall.Getegid),
		"Getenv":                        reflect.ValueOf(syscall.Getenv),
		"Geteuid":                       reflect.ValueOf(syscall.Geteuid),
		"Getgid":                        reflect.ValueOf(syscall.Getgid),
		"Getgroups":                     reflect.ValueOf(syscall.Getgroups),
		"Getkerninfo":                   reflect.ValueOf(syscall.Getkerninfo),
		"Getpagesize":                   reflect.ValueOf(syscall.Getpagesize),
		"Getpeername":                   reflect.ValueOf(syscall.Getpeername),
		"Getpid":                        reflect.ValueOf(syscall.Getpid),
		"Getppid":                       reflect.ValueOf(syscall.Getppid),
		"Getpriority":                   reflect.ValueOf(syscall.Getpriority),
		"Getrlimit":                     reflect.ValueOf(syscall.Getrlimit),
		"Getrusage":                     reflect.ValueOf(syscall.Getrusage),
		"Getsockname":                   reflect.ValueOf(syscall.Getsockname),
		"GetsockoptInt":                 reflect.ValueOf(syscall.GetsockoptInt),
		"Gettimeofday":                  reflect.ValueOf(syscall.Gettimeofday),
		"Getuid":                        reflect.ValueOf(syscall.Getuid),
		"Getwd":                         reflect.ValueOf(syscall.Getwd),
		"HUPCL":                         reflect.ValueOf(constant.MakeFromLiteral("1024", token.INT, 0)),
		"ICANON":                        reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"ICMP6_FILTER":                  reflect.ValueOf(constant.MakeFromLiteral("38", token.INT, 0)),
		"ICMP6_SEC_SEND_DEL":            reflect.ValueOf(constant.MakeFromLiteral("70", token.INT, 0)),
		"ICMP6_SEC_SEND_GET":            reflect.ValueOf(constant.MakeFromLiteral("71", token.INT, 0)),
		"ICMP6_SEC_SEND_SET":            reflect.ValueOf(constant.MakeFromLiteral("68", token.INT, 0)),
		"ICMP6_SEC_SEND_SET_CGA_ADDR":   reflect.ValueOf(constant.MakeFromLiteral("69", token.INT, 0)),
		"ICRNL":                         reflect.ValueOf(constant.MakeFromLiteral("256", token.INT, 0)),
		"IEXTEN":                        reflect.ValueOf(constant.MakeFromLiteral("2097152", token.INT, 0)),
		"IFA_FIRSTALIAS":                reflect.ValueOf(constant.MakeFromLiteral("8192", token.INT, 0)),
		"IFA_ROUTE":                     reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"IFF_64BIT":                     reflect.ValueOf(constant.MakeFromLiteral("67108864", token.INT, 0)),
		"IFF_ALLCAST":                   reflect.ValueOf(constant.MakeFromLiteral("131072", token.INT, 0)),
		"IFF_ALLMULTI":                  reflect.ValueOf(constant.MakeFromLiteral("512", token.INT, 0)),
		"IFF_BPF":                       reflect.ValueOf(constant.MakeFromLiteral("134217728", token.INT, 0)),
		"IFF_BRIDGE":                    reflect.ValueOf(constant.MakeFromLiteral("262144", token.INT, 0)),
		"IFF_BROADCAST":                 reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"IFF_CANTCHANGE":                reflect.ValueOf(constant.MakeFromLiteral("527442", token.INT, 0)),
		"IFF_CHECKSUM_OFFLOAD":          reflect.ValueOf(constant.MakeFromLiteral("268435456", token.INT, 0)),
		"IFF_D1":                        reflect.ValueOf(constant.MakeFromLiteral("32768", token.INT, 0)),
		"IFF_D2":                        reflect.ValueOf(constant.MakeFromLiteral("16384", token.INT, 0)),
		"IFF_D3":                        reflect.ValueOf(constant.MakeFromLiteral("8192", token.INT, 0)),
		"IFF_D4":                        reflect.ValueOf(constant.MakeFromLiteral("4096", token.INT, 0)),
		"IFF_DEBUG":                     reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"IFF_DEVHEALTH":                 reflect.ValueOf(constant.MakeFromLiteral("16384", token.INT, 0)),
		"IFF_DO_HW_LOOPBACK":            reflect.ValueOf(constant.MakeFromLiteral("65536", token.INT, 0)),
		"IFF_GROUP_ROUTING":             reflect.ValueOf(constant.MakeFromLiteral("33554432", token.INT, 0)),
		"IFF_IFBUFMGT":                  reflect.ValueOf(constant.MakeFromLiteral("8388608", token.INT, 0)),
		"IFF_LINK0":                     reflect.ValueOf(constant.MakeFromLiteral("1048576", token.INT, 0)),
		"IFF_LINK1":                     reflect.ValueOf(constant.MakeFromLiteral("2097152", token.INT, 0)),
		"IFF_LINK2":                     reflect.ValueOf(constant.MakeFromLiteral("4194304", token.INT, 0)),
		"IFF_LOOPBACK":                  reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"IFF_MULTICAST":                 reflect.ValueOf(constant.MakeFromLiteral("524288", token.INT, 0)),
		"IFF_NOARP":                     reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"IFF_NOECHO":                    reflect.ValueOf(constant.MakeFromLiteral("2048", token.INT, 0)),
		"IFF_NOTRAILERS":                reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"IFF_OACTIVE":                   reflect.ValueOf(constant.MakeFromLiteral("1024", token.INT, 0)),
		"IFF_POINTOPOINT":               reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"IFF_PROMISC":                   reflect.ValueOf(constant.MakeFromLiteral("256", token.INT, 0)),
		"IFF_PSEG":                      reflect.ValueOf(constant.MakeFromLiteral("1073741824", token.INT, 0)),
		"IFF_RUNNING":                   reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"IFF_SIMPLEX":                   reflect.ValueOf(constant.MakeFromLiteral("2048", token.INT, 0)),
		"IFF_SNAP":                      reflect.ValueOf(constant.MakeFromLiteral("32768", token.INT, 0)),
		"IFF_TCP_DISABLE_CKSUM":         reflect.ValueOf(constant.MakeFromLiteral("536870912", token.INT, 0)),
		"IFF_TCP_NOCKSUM":               reflect.ValueOf(constant.MakeFromLiteral("16777216", token.INT, 0)),
		"IFF_UP":                        reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"IFF_VIPA":                      reflect.ValueOf(constant.MakeFromLiteral("2147483648", token.INT, 0)),
		"IFNAMSIZ":                      reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"IFO_FLUSH":                     reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"IFT_1822":                      reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"IFT_AAL5":                      reflect.ValueOf(constant.MakeFromLiteral("49", token.INT, 0)),
		"IFT_ARCNET":                    reflect.ValueOf(constant.MakeFromLiteral("35", token.INT, 0)),
		"IFT_ARCNETPLUS":                reflect.ValueOf(constant.MakeFromLiteral("36", token.INT, 0)),
		"IFT_ATM":                       reflect.ValueOf(constant.MakeFromLiteral("37", token.INT, 0)),
		"IFT_CEPT":                      reflect.ValueOf(constant.MakeFromLiteral("19", token.INT, 0)),
		"IFT_CLUSTER":                   reflect.ValueOf(constant.MakeFromLiteral("62", token.INT, 0)),
		"IFT_DS3":                       reflect.ValueOf(constant.MakeFromLiteral("30", token.INT, 0)),
		"IFT_EON":                       reflect.ValueOf(constant.MakeFromLiteral("25", token.INT, 0)),
		"IFT_ETHER":                     reflect.ValueOf(constant.MakeFromLiteral("6", token.INT, 0)),
		"IFT_FCS":                       reflect.ValueOf(constant.MakeFromLiteral("58", token.INT, 0)),
		"IFT_FDDI":                      reflect.ValueOf(constant.MakeFromLiteral("15", token.INT, 0)),
		"IFT_FRELAY":                    reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"IFT_FRELAYDCE":                 reflect.ValueOf(constant.MakeFromLiteral("44", token.INT, 0)),
		"IFT_GIFTUNNEL":                 reflect.ValueOf(constant.MakeFromLiteral("60", token.INT, 0)),
		"IFT_HDH1822":                   reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"IFT_HF":                        reflect.ValueOf(constant.MakeFromLiteral("61", token.INT, 0)),
		"IFT_HIPPI":                     reflect.ValueOf(constant.MakeFromLiteral("47", token.INT, 0)),
		"IFT_HSSI":                      reflect.ValueOf(constant.MakeFromLiteral("46", token.INT, 0)),
		"IFT_HY":                        reflect.ValueOf(constant.MakeFromLiteral("14", token.INT, 0)),
		"IFT_IB":                        reflect.ValueOf(constant.MakeFromLiteral("199", token.INT, 0)),
		"IFT_ISDNBASIC":                 reflect.ValueOf(constant.MakeFromLiteral("20", token.INT, 0)),
		"IFT_ISDNPRIMARY":               reflect.ValueOf(constant.MakeFromLiteral("21", token.INT, 0)),
		"IFT_ISO88022LLC":               reflect.ValueOf(constant.MakeFromLiteral("41", token.INT, 0)),
		"IFT_ISO88023":                  reflect.ValueOf(constant.MakeFromLiteral("7", token.INT, 0)),
		"IFT_ISO88024":                  reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"IFT_ISO88025":                  reflect.ValueOf(constant.MakeFromLiteral("9", token.INT, 0)),
		"IFT_ISO88026":                  reflect.ValueOf(constant.MakeFromLiteral("10", token.INT, 0)),
		"IFT_LAPB":                      reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"IFT_LOCALTALK":                 reflect.ValueOf(constant.MakeFromLiteral("42", token.INT, 0)),
		"IFT_LOOP":                      reflect.ValueOf(constant.MakeFromLiteral("24", token.INT, 0)),
		"IFT_MIOX25":                    reflect.ValueOf(constant.MakeFromLiteral("38", token.INT, 0)),
		"IFT_MODEM":                     reflect.ValueOf(constant.MakeFromLiteral("48", token.INT, 0)),
		"IFT_NSIP":                      reflect.ValueOf(constant.MakeFromLiteral("27", token.INT, 0)),
		"IFT_OTHER":                     reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"IFT_P10":                       reflect.ValueOf(constant.MakeFromLiteral("12", token.INT, 0)),
		"IFT_P80":                       reflect.ValueOf(constant.MakeFromLiteral("13", token.INT, 0)),
		"IFT_PARA":                      reflect.ValueOf(constant.MakeFromLiteral("34", token.INT, 0)),
		"IFT_PPP":                       reflect.ValueOf(constant.MakeFromLiteral("23", token.INT, 0)),
		"IFT_PROPMUX":                   reflect.ValueOf(constant.MakeFromLiteral("54", token.INT, 0)),
		"IFT_PROPVIRTUAL":               reflect.ValueOf(constant.MakeFromLiteral("53", token.INT, 0)),
		"IFT_PTPSERIAL":                 reflect.ValueOf(constant.MakeFromLiteral("22", token.INT, 0)),
		"IFT_RS232":                     reflect.ValueOf(constant.MakeFromLiteral("33", token.INT, 0)),
		"IFT_SDLC":                      reflect.ValueOf(constant.MakeFromLiteral("17", token.INT, 0)),
		"IFT_SIP":                       reflect.ValueOf(constant.MakeFromLiteral("31", token.INT, 0)),
		"IFT_SLIP":                      reflect.ValueOf(constant.MakeFromLiteral("28", token.INT, 0)),
		"IFT_SMDSDXI":                   reflect.ValueOf(constant.MakeFromLiteral("43", token.INT, 0)),
		"IFT_SMDSICIP":                  reflect.ValueOf(constant.MakeFromLiteral("52", token.INT, 0)),
		"IFT_SN":                        reflect.ValueOf(constant.MakeFromLiteral("56", token.INT, 0)),
		"IFT_SONET":                     reflect.ValueOf(constant.MakeFromLiteral("39", token.INT, 0)),
		"IFT_SONETPATH":                 reflect.ValueOf(constant.MakeFromLiteral("50", token.INT, 0)),
		"IFT_SONETVT":                   reflect.ValueOf(constant.MakeFromLiteral("51", token.INT, 0)),
		"IFT_SP":                        reflect.ValueOf(constant.MakeFromLiteral("57", token.INT, 0)),
		"IFT_STARLAN":                   reflect.ValueOf(constant.MakeFromLiteral("11", token.INT, 0)),
		"IFT_T1":                        reflect.ValueOf(constant.MakeFromLiteral("18", token.INT, 0)),
		"IFT_TUNNEL":                    reflect.ValueOf(constant.MakeFromLiteral("59", token.INT, 0)),
		"IFT_ULTRA":                     reflect.ValueOf(constant.MakeFromLiteral("29", token.INT, 0)),
		"IFT_V35":                       reflect.ValueOf(constant.MakeFromLiteral("45", token.INT, 0)),
		"IFT_VIPA":                      reflect.ValueOf(constant.MakeFromLiteral("55", token.INT, 0)),
		"IFT_X25":                       reflect.ValueOf(constant.MakeFromLiteral("5", token.INT, 0)),
		"IFT_X25DDN":                    reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"IFT_X25PLE":                    reflect.ValueOf(constant.MakeFromLiteral("40", token.INT, 0)),
		"IFT_XETHER":                    reflect.ValueOf(constant.MakeFromLiteral("26", token.INT, 0)),
		"IGNBRK":                        reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"IGNCR":                         reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"IGNPAR":                        reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"IMAXBEL":                       reflect.ValueOf(constant.MakeFromLiteral("65536", token.INT, 0)),
		"INLCR":                         reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"INPCK":                         reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"IN_CLASSA_HOST":                reflect.ValueOf(constant.MakeFromLiteral("16777215", token.INT, 0)),
		"IN_CLASSA_MAX":                 reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"IN_CLASSA_NET":                 reflect.ValueOf(constant.MakeFromLiteral("4278190080", token.INT, 0)),
		"IN_CLASSA_NSHIFT":              reflect.ValueOf(constant.MakeFromLiteral("24", token.INT, 0)),
		"IN_CLASSB_HOST":                reflect.ValueOf(constant.MakeFromLiteral("65535", token.INT, 0)),
		"IN_CLASSB_MAX":                 reflect.ValueOf(constant.MakeFromLiteral("65536", token.INT, 0)),
		"IN_CLASSB_NET":                 reflect.ValueOf(constant.MakeFromLiteral("4294901760", token.INT, 0)),
		"IN_CLASSB_NSHIFT":              reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"IN_CLASSC_HOST":                reflect.ValueOf(constant.MakeFromLiteral("255", token.INT, 0)),
		"IN_CLASSC_NET":                 reflect.ValueOf(constant.MakeFromLiteral("4294967040", token.INT, 0)),
		"IN_CLASSC_NSHIFT":              reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"IN_CLASSD_HOST":                reflect.ValueOf(constant.MakeFromLiteral("268435455", token.INT, 0)),
		"IN_CLASSD_NET":                 reflect.ValueOf(constant.MakeFromLiteral("4026531840", token.INT, 0)),
		"IN_CLASSD_NSHIFT":              reflect.ValueOf(constant.MakeFromLiteral("28", token.INT, 0)),
		"IN_LOOPBACKNET":                reflect.ValueOf(constant.MakeFromLiteral("127", token.INT, 0)),
		"IN_USE":                        reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"IPPROTO_AH":                    reflect.ValueOf(constant.MakeFromLiteral("51", token.INT, 0)),
		"IPPROTO_BIP":                   reflect.ValueOf(constant.MakeFromLiteral("83", token.INT, 0)),
		"IPPROTO_DSTOPTS":               reflect.ValueOf(constant.MakeFromLiteral("60", token.INT, 0)),
		"IPPROTO_EGP":                   reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"IPPROTO_EON":                   reflect.ValueOf(constant.MakeFromLiteral("80", token.INT, 0)),
		"IPPROTO_ESP":                   reflect.ValueOf(constant.MakeFromLiteral("50", token.INT, 0)),
		"IPPROTO_FRAGMENT":              reflect.ValueOf(constant.MakeFromLiteral("44", token.INT, 0)),
		"IPPROTO_GGP":                   reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"IPPROTO_GIF":                   reflect.ValueOf(constant.MakeFromLiteral("140", token.INT, 0)),
		"IPPROTO_GRE":                   reflect.ValueOf(constant.MakeFromLiteral("47", token.INT, 0)),
		"IPPROTO_HOPOPTS":               reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"IPPROTO_ICMP":                  reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"IPPROTO_ICMPV6":                reflect.ValueOf(constant.MakeFromLiteral("58", token.INT, 0)),
		"IPPROTO_IDP":                   reflect.ValueOf(constant.MakeFromLiteral("22", token.INT, 0)),
		"IPPROTO_IGMP":                  reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"IPPROTO_IP":                    reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"IPPROTO_IPIP":                  reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"IPPROTO_IPV6":                  reflect.ValueOf(constant.MakeFromLiteral("41", token.INT, 0)),
		"IPPROTO_LOCAL":                 reflect.ValueOf(constant.MakeFromLiteral("63", token.INT, 0)),
		"IPPROTO_MAX":                   reflect.ValueOf(constant.MakeFromLiteral("256", token.INT, 0)),
		"IPPROTO_MH":                    reflect.ValueOf(constant.MakeFromLiteral("135", token.INT, 0)),
		"IPPROTO_NONE":                  reflect.ValueOf(constant.MakeFromLiteral("59", token.INT, 0)),
		"IPPROTO_PUP":                   reflect.ValueOf(constant.MakeFromLiteral("12", token.INT, 0)),
		"IPPROTO_QOS":                   reflect.ValueOf(constant.MakeFromLiteral("45", token.INT, 0)),
		"IPPROTO_RAW":                   reflect.ValueOf(constant.MakeFromLiteral("255", token.INT, 0)),
		"IPPROTO_ROUTING":               reflect.ValueOf(constant.MakeFromLiteral("43", token.INT, 0)),
		"IPPROTO_RSVP":                  reflect.ValueOf(constant.MakeFromLiteral("46", token.INT, 0)),
		"IPPROTO_SCTP":                  reflect.ValueOf(constant.MakeFromLiteral("132", token.INT, 0)),
		"IPPROTO_TCP":                   reflect.ValueOf(constant.MakeFromLiteral("6", token.INT, 0)),
		"IPPROTO_TP":                    reflect.ValueOf(constant.MakeFromLiteral("29", token.INT, 0)),
		"IPPROTO_UDP":                   reflect.ValueOf(constant.MakeFromLiteral("17", token.INT, 0)),
		"IPV6_ADDRFORM":                 reflect.ValueOf(constant.MakeFromLiteral("22", token.INT, 0)),
		"IPV6_ADDR_PREFERENCES":         reflect.ValueOf(constant.MakeFromLiteral("74", token.INT, 0)),
		"IPV6_ADD_MEMBERSHIP":           reflect.ValueOf(constant.MakeFromLiteral("12", token.INT, 0)),
		"IPV6_AIXRAWSOCKET":             reflect.ValueOf(constant.MakeFromLiteral("57", token.INT, 0)),
		"IPV6_CHECKSUM":                 reflect.ValueOf(constant.MakeFromLiteral("39", token.INT, 0)),
		"IPV6_DONTFRAG":                 reflect.ValueOf(constant.MakeFromLiteral("45", token.INT, 0)),
		"IPV6_DROP_MEMBERSHIP":          reflect.ValueOf(constant.MakeFromLiteral("13", token.INT, 0)),
		"IPV6_DSTOPTS":                  reflect.ValueOf(constant.MakeFromLiteral("54", token.INT, 0)),
		"IPV6_FLOWINFO_FLOWLABEL":       reflect.ValueOf(constant.MakeFromLiteral("16777215", token.INT, 0)),
		"IPV6_FLOWINFO_PRIFLOW":         reflect.ValueOf(constant.MakeFromLiteral("268435455", token.INT, 0)),
		"IPV6_FLOWINFO_PRIORITY":        reflect.ValueOf(constant.MakeFromLiteral("251658240", token.INT, 0)),
		"IPV6_FLOWINFO_SRFLAG":          reflect.ValueOf(constant.MakeFromLiteral("268435456", token.INT, 0)),
		"IPV6_FLOWINFO_VERSION":         reflect.ValueOf(constant.MakeFromLiteral("4026531840", token.INT, 0)),
		"IPV6_HOPLIMIT":                 reflect.ValueOf(constant.MakeFromLiteral("40", token.INT, 0)),
		"IPV6_HOPOPTS":                  reflect.ValueOf(constant.MakeFromLiteral("52", token.INT, 0)),
		"IPV6_JOIN_GROUP":               reflect.ValueOf(constant.MakeFromLiteral("12", token.INT, 0)),
		"IPV6_LEAVE_GROUP":              reflect.ValueOf(constant.MakeFromLiteral("13", token.INT, 0)),
		"IPV6_MIPDSTOPTS":               reflect.ValueOf(constant.MakeFromLiteral("54", token.INT, 0)),
		"IPV6_MULTICAST_HOPS":           reflect.ValueOf(constant.MakeFromLiteral("10", token.INT, 0)),
		"IPV6_MULTICAST_IF":             reflect.ValueOf(constant.MakeFromLiteral("9", token.INT, 0)),
		"IPV6_MULTICAST_LOOP":           reflect.ValueOf(constant.MakeFromLiteral("11", token.INT, 0)),
		"IPV6_NEXTHOP":                  reflect.ValueOf(constant.MakeFromLiteral("48", token.INT, 0)),
		"IPV6_NOPROBE":                  reflect.ValueOf(constant.MakeFromLiteral("28", token.INT, 0)),
		"IPV6_PATHMTU":                  reflect.ValueOf(constant.MakeFromLiteral("46", token.INT, 0)),
		"IPV6_PKTINFO":                  reflect.ValueOf(constant.MakeFromLiteral("33", token.INT, 0)),
		"IPV6_PKTOPTIONS":               reflect.ValueOf(constant.MakeFromLiteral("36", token.INT, 0)),
		"IPV6_PRIORITY_10":              reflect.ValueOf(constant.MakeFromLiteral("167772160", token.INT, 0)),
		"IPV6_PRIORITY_11":              reflect.ValueOf(constant.MakeFromLiteral("184549376", token.INT, 0)),
		"IPV6_PRIORITY_12":              reflect.ValueOf(constant.MakeFromLiteral("201326592", token.INT, 0)),
		"IPV6_PRIORITY_13":              reflect.ValueOf(constant.MakeFromLiteral("218103808", token.INT, 0)),
		"IPV6_PRIORITY_14":              reflect.ValueOf(constant.MakeFromLiteral("234881024", token.INT, 0)),
		"IPV6_PRIORITY_15":              reflect.ValueOf(constant.MakeFromLiteral("251658240", token.INT, 0)),
		"IPV6_PRIORITY_8":               reflect.ValueOf(constant.MakeFromLiteral("134217728", token.INT, 0)),
		"IPV6_PRIORITY_9":               reflect.ValueOf(constant.MakeFromLiteral("150994944", token.INT, 0)),
		"IPV6_PRIORITY_BULK":            reflect.ValueOf(constant.MakeFromLiteral("67108864", token.INT, 0)),
		"IPV6_PRIORITY_CONTROL":         reflect.ValueOf(constant.MakeFromLiteral("117440512", token.INT, 0)),
		"IPV6_PRIORITY_FILLER":          reflect.ValueOf(constant.MakeFromLiteral("16777216", token.INT, 0)),
		"IPV6_PRIORITY_INTERACTIVE":     reflect.ValueOf(constant.MakeFromLiteral("100663296", token.INT, 0)),
		"IPV6_PRIORITY_RESERVED1":       reflect.ValueOf(constant.MakeFromLiteral("50331648", token.INT, 0)),
		"IPV6_PRIORITY_RESERVED2":       reflect.ValueOf(constant.MakeFromLiteral("83886080", token.INT, 0)),
		"IPV6_PRIORITY_UNATTENDED":      reflect.ValueOf(constant.MakeFromLiteral("33554432", token.INT, 0)),
		"IPV6_PRIORITY_UNCHARACTERIZED": reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"IPV6_RECVDSTOPTS":              reflect.ValueOf(constant.MakeFromLiteral("56", token.INT, 0)),
		"IPV6_RECVHOPLIMIT":             reflect.ValueOf(constant.MakeFromLiteral("41", token.INT, 0)),
		"IPV6_RECVHOPOPTS":              reflect.ValueOf(constant.MakeFromLiteral("53", token.INT, 0)),
		"IPV6_RECVHOPS":                 reflect.ValueOf(constant.MakeFromLiteral("34", token.INT, 0)),
		"IPV6_RECVIF":                   reflect.ValueOf(constant.MakeFromLiteral("30", token.INT, 0)),
		"IPV6_RECVPATHMTU":              reflect.ValueOf(constant.MakeFromLiteral("47", token.INT, 0)),
		"IPV6_RECVPKTINFO":              reflect.ValueOf(constant.MakeFromLiteral("35", token.INT, 0)),
		"IPV6_RECVRTHDR":                reflect.ValueOf(constant.MakeFromLiteral("51", token.INT, 0)),
		"IPV6_RECVSRCRT":                reflect.ValueOf(constant.MakeFromLiteral("29", token.INT, 0)),
		"IPV6_RECVTCLASS":               reflect.ValueOf(constant.MakeFromLiteral("42", token.INT, 0)),
		"IPV6_RTHDR":                    reflect.ValueOf(constant.MakeFromLiteral("50", token.INT, 0)),
		"IPV6_RTHDRDSTOPTS":             reflect.ValueOf(constant.MakeFromLiteral("55", token.INT, 0)),
		"IPV6_RTHDR_TYPE_0":             reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"IPV6_RTHDR_TYPE_2":             reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"IPV6_SENDIF":                   reflect.ValueOf(constant.MakeFromLiteral("31", token.INT, 0)),
		"IPV6_SRFLAG_LOOSE":             reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"IPV6_SRFLAG_STRICT":            reflect.ValueOf(constant.MakeFromLiteral("268435456", token.INT, 0)),
		"IPV6_TCLASS":                   reflect.ValueOf(constant.MakeFromLiteral("43", token.INT, 0)),
		"IPV6_TOKEN_LENGTH":             reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"IPV6_UNICAST_HOPS":             reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"IPV6_USE_MIN_MTU":              reflect.ValueOf(constant.MakeFromLiteral("44", token.INT, 0)),
		"IPV6_V6ONLY":                   reflect.ValueOf(constant.MakeFromLiteral("37", token.INT, 0)),
		"IPV6_VERSION":                  reflect.ValueOf(constant.MakeFromLiteral("1610612736", token.INT, 0)),
		"IP_ADDRFORM":                   reflect.ValueOf(constant.MakeFromLiteral("22", token.INT, 0)),
		"IP_ADD_MEMBERSHIP":             reflect.ValueOf(constant.MakeFromLiteral("12", token.INT, 0)),
		"IP_ADD_SOURCE_MEMBERSHIP":      reflect.ValueOf(constant.MakeFromLiteral("60", token.INT, 0)),
		"IP_BLOCK_SOURCE":               reflect.ValueOf(constant.MakeFromLiteral("58", token.INT, 0)),
		"IP_BROADCAST_IF":               reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"IP_CACHE_LINE_SIZE":            reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"IP_DEFAULT_MULTICAST_LOOP":     reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"IP_DEFAULT_MULTICAST_TTL":      reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"IP_DF":                         reflect.ValueOf(constant.MakeFromLiteral("16384", token.INT, 0)),
		"IP_DHCPMODE":                   reflect.ValueOf(constant.MakeFromLiteral("17", token.INT, 0)),
		"IP_DONTFRAG":                   reflect.ValueOf(constant.MakeFromLiteral("25", token.INT, 0)),
		"IP_DROP_MEMBERSHIP":            reflect.ValueOf(constant.MakeFromLiteral("13", token.INT, 0)),
		"IP_DROP_SOURCE_MEMBERSHIP":     reflect.ValueOf(constant.MakeFromLiteral("61", token.INT, 0)),
		"IP_FINDPMTU":                   reflect.ValueOf(constant.MakeFromLiteral("26", token.INT, 0)),
		"IP_HDRINCL":                    reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"IP_INC_MEMBERSHIPS":            reflect.ValueOf(constant.MakeFromLiteral("20", token.INT, 0)),
		"IP_INIT_MEMBERSHIP":            reflect.ValueOf(constant.MakeFromLiteral("20", token.INT, 0)),
		"IP_MAXPACKET":                  reflect.ValueOf(constant.MakeFromLiteral("65535", token.INT, 0)),
		"IP_MF":                         reflect.ValueOf(constant.MakeFromLiteral("8192", token.INT, 0)),
		"IP_MSS":                        reflect.ValueOf(constant.MakeFromLiteral("576", token.INT, 0)),
		"IP_MULTICAST_HOPS":             reflect.ValueOf(constant.MakeFromLiteral("10", token.INT, 0)),
		"IP_MULTICAST_IF":               reflect.ValueOf(constant.MakeFromLiteral("9", token.INT, 0)),
		"IP_MULTICAST_LOOP":             reflect.ValueOf(constant.MakeFromLiteral("11", token.INT, 0)),
		"IP_MULTICAST_TTL":              reflect.ValueOf(constant.MakeFromLiteral("10", token.INT, 0)),
		"IP_OPT":                        reflect.ValueOf(constant.MakeFromLiteral("27", token.INT, 0)),
		"IP_OPTIONS":                    reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"IP_PMTUAGE":                    reflect.ValueOf(constant.MakeFromLiteral("27", token.INT, 0)),
		"IP_RECVDSTADDR":                reflect.ValueOf(constant.MakeFromLiteral("7", token.INT, 0)),
		"IP_RECVIF":                     reflect.ValueOf(constant.MakeFromLiteral("20", token.INT, 0)),
		"IP_RECVIFINFO":                 reflect.ValueOf(constant.MakeFromLiteral("15", token.INT, 0)),
		"IP_RECVINTERFACE":              reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"IP_RECVMACHDR":                 reflect.ValueOf(constant.MakeFromLiteral("14", token.INT, 0)),
		"IP_RECVOPTS":                   reflect.ValueOf(constant.MakeFromLiteral("5", token.INT, 0)),
		"IP_RECVRETOPTS":                reflect.ValueOf(constant.MakeFromLiteral("6", token.INT, 0)),
		"IP_RECVTTL":                    reflect.ValueOf(constant.MakeFromLiteral("34", token.INT, 0)),
		"IP_RETOPTS":                    reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"IP_SOURCE_FILTER":              reflect.ValueOf(constant.MakeFromLiteral("72", token.INT, 0)),
		"IP_TOS":                        reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"IP_TTL":                        reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"IP_UNBLOCK_SOURCE":             reflect.ValueOf(constant.MakeFromLiteral("59", token.INT, 0)),
		"IP_UNICAST_HOPS":               reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"ISIG":                          reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"ISTRIP":                        reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"IXANY":                         reflect.ValueOf(constant.MakeFromLiteral("4096", token.INT, 0)),
		"IXOFF":                         reflect.ValueOf(constant.MakeFromLiteral("1024", token.INT, 0)),
		"IXON":                          reflect.ValueOf(constant.MakeFromLiteral("512", token.INT, 0)),
		"I_FLUSH":                       reflect.ValueOf(constant.MakeFromLiteral("536892165", token.INT, 0)),
		"ImplementsGetwd":               reflect.ValueOf(syscall.ImplementsGetwd),
		"LNOFLSH":                       reflect.ValueOf(constant.MakeFromLiteral("32768", token.INT, 0)),
		"LOCK_EX":                       reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"LOCK_NB":                       reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"LOCK_SH":                       reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"LOCK_UN":                       reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"Lchown":                        reflect.ValueOf(syscall.Lchown),
		"Link":                          reflect.ValueOf(syscall.Link),
		"Listen":                        reflect.ValueOf(syscall.Listen),
		"Lstat":                         reflect.ValueOf(syscall.Lstat),
		"MADV_DONTNEED":                 reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"MADV_NORMAL":                   reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"MADV_RANDOM":                   reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"MADV_SEQUENTIAL":               reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"MADV_SPACEAVAIL":               reflect.ValueOf(constant.MakeFromLiteral("5", token.INT, 0)),
		"MADV_WILLNEED":                 reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"MAP_ANON":                      reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"MAP_ANONYMOUS":                 reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"MAP_FILE":                      reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"MAP_FIXED":                     reflect.ValueOf(constant.MakeFromLiteral("256", token.INT, 0)),
		"MAP_PRIVATE":                   reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"MAP_SHARED":                    reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"MAP_TYPE":                      reflect.ValueOf(constant.MakeFromLiteral("240", token.INT, 0)),
		"MAP_VARIABLE":                  reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"MCL_CURRENT":                   reflect.ValueOf(constant.MakeFromLiteral("256", token.INT, 0)),
		"MCL_FUTURE":                    reflect.ValueOf(constant.MakeFromLiteral("512", token.INT, 0)),
		"MSG_ANY":                       reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"MSG_ARGEXT":                    reflect.ValueOf(constant.MakeFromLiteral("1024", token.INT, 0)),
		"MSG_BAND":                      reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"MSG_COMPAT":                    reflect.ValueOf(constant.MakeFromLiteral("32768", token.INT, 0)),
		"MSG_CTRUNC":                    reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"MSG_DONTROUTE":                 reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"MSG_EOR":                       reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"MSG_HIPRI":                     reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"MSG_MAXIOVLEN":                 reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"MSG_MPEG2":                     reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"MSG_NONBLOCK":                  reflect.ValueOf(constant.MakeFromLiteral("16384", token.INT, 0)),
		"MSG_NOSIGNAL":                  reflect.ValueOf(constant.MakeFromLiteral("256", token.INT, 0)),
		"MSG_OOB":                       reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"MSG_PEEK":                      reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"MSG_TRUNC":                     reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"MSG_WAITALL":                   reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"MSG_WAITFORONE":                reflect.ValueOf(constant.MakeFromLiteral("512", token.INT, 0)),
		"MS_ASYNC":                      reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"MS_EINTR":                      reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"MS_INVALIDATE":                 reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"MS_PER_SEC":                    reflect.ValueOf(constant.MakeFromLiteral("1000", token.INT, 0)),
		"MS_SYNC":                       reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"Mkdir":                         reflect.ValueOf(syscall.Mkdir),
		"Mkdirat":                       reflect.ValueOf(syscall.Mkdirat),
		"Mknodat":                       reflect.ValueOf(syscall.Mknodat),
		"Mmap":                          reflect.ValueOf(syscall.Mmap),
		"Munmap":                        reflect.ValueOf(syscall.Munmap),
		"NOFLSH":                        reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"NOFLUSH":                       reflect.ValueOf(constant.MakeFromLiteral("2147483648", token.INT, 0)),
		"NsecToTimespec":                reflect.ValueOf(syscall.NsecToTimespec),
		"NsecToTimeval":                 reflect.ValueOf(syscall.NsecToTimeval),
		"OCRNL":                         reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"OFDEL":                         reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"OFILL":                         reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"ONLCR":                         reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"ONLRET":                        reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"ONOCR":                         reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"ONOEOT":                        reflect.ValueOf(constant.MakeFromLiteral("524288", token.INT, 0)),
		"OPOST":                         reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"O_ACCMODE":                     reflect.ValueOf(constant.MakeFromLiteral("35", token.INT, 0)),
		"O_APPEND":                      reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"O_CIO":                         reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"O_CIOR":                        reflect.ValueOf(constant.MakeFromLiteral("34359738368", token.INT, 0)),
		"O_CLOEXEC":                     reflect.ValueOf(constant.MakeFromLiteral("8388608", token.INT, 0)),
		"O_CREAT":                       reflect.ValueOf(constant.MakeFromLiteral("256", token.INT, 0)),
		"O_DEFER":                       reflect.ValueOf(constant.MakeFromLiteral("8192", token.INT, 0)),
		"O_DELAY":                       reflect.ValueOf(constant.MakeFromLiteral("16384", token.INT, 0)),
		"O_DIRECT":                      reflect.ValueOf(constant.MakeFromLiteral("134217728", token.INT, 0)),
		"O_DIRECTORY":                   reflect.ValueOf(constant.MakeFromLiteral("524288", token.INT, 0)),
		"O_DSYNC":                       reflect.ValueOf(constant.MakeFromLiteral("4194304", token.INT, 0)),
		"O_EFSOFF":                      reflect.ValueOf(constant.MakeFromLiteral("17179869184", token.INT, 0)),
		"O_EFSON":                       reflect.ValueOf(constant.MakeFromLiteral("8589934592", token.INT, 0)),
		"O_EXCL":                        reflect.ValueOf(constant.MakeFromLiteral("1024", token.INT, 0)),
		"O_EXEC":                        reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"O_LARGEFILE":                   reflect.ValueOf(constant.MakeFromLiteral("67108864", token.INT, 0)),
		"O_NDELAY":                      reflect.ValueOf(constant.MakeFromLiteral("32768", token.INT, 0)),
		"O_NOCACHE":                     reflect.ValueOf(constant.MakeFromLiteral("1048576", token.INT, 0)),
		"O_NOCTTY":                      reflect.ValueOf(constant.MakeFromLiteral("2048", token.INT, 0)),
		"O_NOFOLLOW":                    reflect.ValueOf(constant.MakeFromLiteral("16777216", token.INT, 0)),
		"O_NONBLOCK":                    reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"O_NONE":                        reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"O_NSHARE":                      reflect.ValueOf(constant.MakeFromLiteral("65536", token.INT, 0)),
		"O_RAW":                         reflect.ValueOf(constant.MakeFromLiteral("4294967296", token.INT, 0)),
		"O_RDONLY":                      reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"O_RDWR":                        reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"O_RSHARE":                      reflect.ValueOf(constant.MakeFromLiteral("4096", token.INT, 0)),
		"O_RSYNC":                       reflect.ValueOf(constant.MakeFromLiteral("2097152", token.INT, 0)),
		"O_SEARCH":                      reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"O_SNAPSHOT":                    reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"O_SYNC":                        reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"O_TRUNC":                       reflect.ValueOf(constant.MakeFromLiteral("512", token.INT, 0)),
		"O_TTY_INIT":                    reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"O_WRONLY":                      reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"Open":                          reflect.ValueOf(syscall.Open),
		"Openat":                        reflect.ValueOf(syscall.Openat),
		"PARENB":                        reflect.ValueOf(constant.MakeFromLiteral("256", token.INT, 0)),
		"PAREXT":                        reflect.ValueOf(constant.MakeFromLiteral("1048576", token.INT, 0)),
		"PARMRK":                        reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"PARODD":                        reflect.ValueOf(constant.MakeFromLiteral("512", token.INT, 0)),
		"PENDIN":                        reflect.ValueOf(constant.MakeFromLiteral("536870912", token.INT, 0)),
		"PRIO_PGRP":                     reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"PRIO_PROCESS":                  reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"PRIO_USER":                     reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"PROT_EXEC":                     reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"PROT_NONE":                     reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"PROT_READ":                     reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"PROT_WRITE":                    reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"PR_64BIT":                      reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"PR_ADDR":                       reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"PR_ARGEXT":                     reflect.ValueOf(constant.MakeFromLiteral("1024", token.INT, 0)),
		"PR_ATOMIC":                     reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"PR_CONNREQUIRED":               reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"PR_FASTHZ":                     reflect.ValueOf(constant.MakeFromLiteral("5", token.INT, 0)),
		"PR_INP":                        reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"PR_INTRLEVEL":                  reflect.ValueOf(constant.MakeFromLiteral("32768", token.INT, 0)),
		"PR_MLS":                        reflect.ValueOf(constant.MakeFromLiteral("256", token.INT, 0)),
		"PR_MLS_1_LABEL":                reflect.ValueOf(constant.MakeFromLiteral("512", token.INT, 0)),
		"PR_NOEOR":                      reflect.ValueOf(constant.MakeFromLiteral("16384", token.INT, 0)),
		"PR_RIGHTS":                     reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"PR_SLOWHZ":                     reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"PR_WANTRCVD":                   reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"PTRACE_CONT":                   reflect.ValueOf(constant.MakeFromLiteral("7", token.INT, 0)),
		"PTRACE_KILL":                   reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"PTRACE_TRACEME":                reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"PT_ATTACH":                     reflect.ValueOf(constant.MakeFromLiteral("30", token.INT, 0)),
		"PT_CLEAR":                      reflect.ValueOf(constant.MakeFromLiteral("38", token.INT, 0)),
		"PT_COMMAND_MAX":                reflect.ValueOf(constant.MakeFromLiteral("69", token.INT, 0)),
		"PT_CONTINUE":                   reflect.ValueOf(constant.MakeFromLiteral("7", token.INT, 0)),
		"PT_DETACH":                     reflect.ValueOf(constant.MakeFromLiteral("31", token.INT, 0)),
		"PT_GET_UKEY":                   reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"PT_KILL":                       reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"PT_LDINFO":                     reflect.ValueOf(constant.MakeFromLiteral("34", token.INT, 0)),
		"PT_LDXINFO":                    reflect.ValueOf(constant.MakeFromLiteral("39", token.INT, 0)),
		"PT_MULTI":                      reflect.ValueOf(constant.MakeFromLiteral("35", token.INT, 0)),
		"PT_NEXT":                       reflect.ValueOf(constant.MakeFromLiteral("36", token.INT, 0)),
		"PT_QUERY":                      reflect.ValueOf(constant.MakeFromLiteral("40", token.INT, 0)),
		"PT_READ_BLOCK":                 reflect.ValueOf(constant.MakeFromLiteral("17", token.INT, 0)),
		"PT_READ_D":                     reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"PT_READ_FPR":                   reflect.ValueOf(constant.MakeFromLiteral("12", token.INT, 0)),
		"PT_READ_GPR":                   reflect.ValueOf(constant.MakeFromLiteral("11", token.INT, 0)),
		"PT_READ_I":                     reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"PT_REATT":                      reflect.ValueOf(constant.MakeFromLiteral("33", token.INT, 0)),
		"PT_REGSET":                     reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"PT_SET":                        reflect.ValueOf(constant.MakeFromLiteral("37", token.INT, 0)),
		"PT_STEP":                       reflect.ValueOf(constant.MakeFromLiteral("9", token.INT, 0)),
		"PT_TRACE_ME":                   reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"PT_WATCH":                      reflect.ValueOf(constant.MakeFromLiteral("41", token.INT, 0)),
		"PT_WRITE_BLOCK":                reflect.ValueOf(constant.MakeFromLiteral("19", token.INT, 0)),
		"PT_WRITE_D":                    reflect.ValueOf(constant.MakeFromLiteral("5", token.INT, 0)),
		"PT_WRITE_FPR":                  reflect.ValueOf(constant.MakeFromLiteral("15", token.INT, 0)),
		"PT_WRITE_GPR":                  reflect.ValueOf(constant.MakeFromLiteral("14", token.INT, 0)),
		"PT_WRITE_I":                    reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"ParseDirent":                   reflect.ValueOf(syscall.ParseDirent),
		"ParseSocketControlMessage":     reflect.ValueOf(syscall.ParseSocketControlMessage),
		"ParseUnixRights":               reflect.ValueOf(syscall.ParseUnixRights),
		"PathMax":                       reflect.ValueOf(constant.MakeFromLiteral("1023", token.INT, 0)),
		"Pipe":                          reflect.ValueOf(syscall.Pipe),
		"Pread":                         reflect.ValueOf(syscall.Pread),
		"Pwrite":                        reflect.ValueOf(syscall.Pwrite),
		"RLIMIT_AS":                     reflect.ValueOf(constant.MakeFromLiteral("6", token.INT, 0)),
		"RLIMIT_CORE":                   reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"RLIMIT_CPU":                    reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"RLIMIT_DATA":                   reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"RLIMIT_FSIZE":                  reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"RLIMIT_NOFILE":                 reflect.ValueOf(constant.MakeFromLiteral("7", token.INT, 0)),
		"RLIMIT_STACK":                  reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"RLIM_INFINITY":                 reflect.ValueOf(constant.MakeFromLiteral("9223372036854775807", token.INT, 0)),
		"RTAX_AUTHOR":                   reflect.ValueOf(constant.MakeFromLiteral("6", token.INT, 0)),
		"RTAX_BRD":                      reflect.ValueOf(constant.MakeFromLiteral("7", token.INT, 0)),
		"RTAX_DST":                      reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"RTAX_GATEWAY":                  reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"RTAX_GENMASK":                  reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"RTAX_IFA":                      reflect.ValueOf(constant.MakeFromLiteral("5", token.INT, 0)),
		"RTAX_IFP":                      reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"RTAX_MAX":                      reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"RTAX_NETMASK":                  reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"RTA_AUTHOR":                    reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"RTA_BRD":                       reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"RTA_DOWNSTREAM":                reflect.ValueOf(constant.MakeFromLiteral("256", token.INT, 0)),
		"RTA_DST":                       reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"RTA_GATEWAY":                   reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"RTA_GENMASK":                   reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"RTA_IFA":                       reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"RTA_IFP":                       reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"RTA_NETMASK":                   reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"RTF_ACTIVE_DGD":                reflect.ValueOf(constant.MakeFromLiteral("16777216", token.INT, 0)),
		"RTF_BCE":                       reflect.ValueOf(constant.MakeFromLiteral("524288", token.INT, 0)),
		"RTF_BLACKHOLE":                 reflect.ValueOf(constant.MakeFromLiteral("4096", token.INT, 0)),
		"RTF_BROADCAST":                 reflect.ValueOf(constant.MakeFromLiteral("4194304", token.INT, 0)),
		"RTF_BUL":                       reflect.ValueOf(constant.MakeFromLiteral("8192", token.INT, 0)),
		"RTF_CLONE":                     reflect.ValueOf(constant.MakeFromLiteral("65536", token.INT, 0)),
		"RTF_CLONED":                    reflect.ValueOf(constant.MakeFromLiteral("131072", token.INT, 0)),
		"RTF_CLONING":                   reflect.ValueOf(constant.MakeFromLiteral("256", token.INT, 0)),
		"RTF_DONE":                      reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"RTF_DYNAMIC":                   reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"RTF_FREE_IN_PROG":              reflect.ValueOf(constant.MakeFromLiteral("67108864", token.INT, 0)),
		"RTF_GATEWAY":                   reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"RTF_HOST":                      reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"RTF_LLINFO":                    reflect.ValueOf(constant.MakeFromLiteral("1024", token.INT, 0)),
		"RTF_LOCAL":                     reflect.ValueOf(constant.MakeFromLiteral("2097152", token.INT, 0)),
		"RTF_MASK":                      reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"RTF_MODIFIED":                  reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"RTF_MULTICAST":                 reflect.ValueOf(constant.MakeFromLiteral("8388608", token.INT, 0)),
		"RTF_PERMANENT6":                reflect.ValueOf(constant.MakeFromLiteral("134217728", token.INT, 0)),
		"RTF_PINNED":                    reflect.ValueOf(constant.MakeFromLiteral("1048576", token.INT, 0)),
		"RTF_PROTO1":                    reflect.ValueOf(constant.MakeFromLiteral("32768", token.INT, 0)),
		"RTF_PROTO2":                    reflect.ValueOf(constant.MakeFromLiteral("16384", token.INT, 0)),
		"RTF_PROTO3":                    reflect.ValueOf(constant.MakeFromLiteral("262144", token.INT, 0)),
		"RTF_REJECT":                    reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"RTF_SMALLMTU":                  reflect.ValueOf(constant.MakeFromLiteral("262144", token.INT, 0)),
		"RTF_STATIC":                    reflect.ValueOf(constant.MakeFromLiteral("2048", token.INT, 0)),
		"RTF_STOPSRCH":                  reflect.ValueOf(constant.MakeFromLiteral("33554432", token.INT, 0)),
		"RTF_UNREACHABLE":               reflect.ValueOf(constant.MakeFromLiteral("268435456", token.INT, 0)),
		"RTF_UP":                        reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"RTF_XRESOLVE":                  reflect.ValueOf(constant.MakeFromLiteral("512", token.INT, 0)),
		"RTM_ADD":                       reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"RTM_CHANGE":                    reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"RTM_DELADDR":                   reflect.ValueOf(constant.MakeFromLiteral("13", token.INT, 0)),
		"RTM_DELETE":                    reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"RTM_EXPIRE":                    reflect.ValueOf(constant.MakeFromLiteral("15", token.INT, 0)),
		"RTM_GET":                       reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"RTM_GETNEXT":                   reflect.ValueOf(constant.MakeFromLiteral("17", token.INT, 0)),
		"RTM_IFINFO":                    reflect.ValueOf(constant.MakeFromLiteral("14", token.INT, 0)),
		"RTM_LOCK":                      reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"RTM_LOSING":                    reflect.ValueOf(constant.MakeFromLiteral("5", token.INT, 0)),
		"RTM_MISS":                      reflect.ValueOf(constant.MakeFromLiteral("7", token.INT, 0)),
		"RTM_NEWADDR":                   reflect.ValueOf(constant.MakeFromLiteral("12", token.INT, 0)),
		"RTM_OLDADD":                    reflect.ValueOf(constant.MakeFromLiteral("9", token.INT, 0)),
		"RTM_OLDDEL":                    reflect.ValueOf(constant.MakeFromLiteral("10", token.INT, 0)),
		"RTM_REDIRECT":                  reflect.ValueOf(constant.MakeFromLiteral("6", token.INT, 0)),
		"RTM_RESOLVE":                   reflect.ValueOf(constant.MakeFromLiteral("11", token.INT, 0)),
		"RTM_RTLOST":                    reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"RTM_RTTUNIT":                   reflect.ValueOf(constant.MakeFromLiteral("1000000", token.INT, 0)),
		"RTM_SAMEADDR":                  reflect.ValueOf(constant.MakeFromLiteral("18", token.INT, 0)),
		"RTM_SET":                       reflect.ValueOf(constant.MakeFromLiteral("19", token.INT, 0)),
		"RTM_VERSION":                   reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"RTM_VERSION_GR":                reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"RTM_VERSION_GR_COMPAT":         reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"RTM_VERSION_POLICY":            reflect.ValueOf(constant.MakeFromLiteral("5", token.INT, 0)),
		"RTM_VERSION_POLICY_EXT":        reflect.ValueOf(constant.MakeFromLiteral("6", token.INT, 0)),
		"RTM_VERSION_POLICY_PRFN":       reflect.ValueOf(constant.MakeFromLiteral("7", token.INT, 0)),
		"RTV_EXPIRE":                    reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"RTV_HOPCOUNT":                  reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"RTV_MTU":                       reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"RTV_RPIPE":                     reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"RTV_RTT":                       reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"RTV_RTTVAR":                    reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"RTV_SPIPE":                     reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"RTV_SSTHRESH":                  reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"RUSAGE_CHILDREN":               reflect.ValueOf(constant.MakeFromLiteral("-1", token.INT, 0)),
		"RUSAGE_SELF":                   reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"RUSAGE_THREAD":                 reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"Read":                          reflect.ValueOf(syscall.Read),
		"ReadDirent":                    reflect.ValueOf(syscall.ReadDirent),
		"Readlink":                      reflect.ValueOf(syscall.Readlink),
		"Recvfrom":                      reflect.ValueOf(syscall.Recvfrom),
		"Recvmsg":                       reflect.ValueOf(syscall.Recvmsg),
		"Rename":                        reflect.ValueOf(syscall.Rename),
		"Renameat":                      reflect.ValueOf(syscall.Renameat),
		"Rmdir":                         reflect.ValueOf(syscall.Rmdir),
		"SCM_RIGHTS":                    reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"SHUT_RD":                       reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"SHUT_RDWR":                     reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"SHUT_WR":                       reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"SIGABRT":                       reflect.ValueOf(syscall.SIGABRT),
		"SIGAIO":                        reflect.ValueOf(syscall.SIGAIO),
		"SIGALRM":                       reflect.ValueOf(syscall.SIGALRM),
		"SIGALRM1":                      reflect.ValueOf(syscall.SIGALRM1),
		"SIGBUS":                        reflect.ValueOf(syscall.SIGBUS),
		"SIGCAPI":                       reflect.ValueOf(syscall.SIGCAPI),
		"SIGCHLD":                       reflect.ValueOf(syscall.SIGCHLD),
		"SIGCLD":                        reflect.ValueOf(syscall.SIGCLD),
		"SIGCONT":                       reflect.ValueOf(syscall.SIGCONT),
		"SIGCPUFAIL":                    reflect.ValueOf(syscall.SIGCPUFAIL),
		"SIGDANGER":                     reflect.ValueOf(syscall.SIGDANGER),
		"SIGEMT":                        reflect.ValueOf(syscall.SIGEMT),
		"SIGFPE":                        reflect.ValueOf(syscall.SIGFPE),
		"SIGGRANT":                      reflect.ValueOf(syscall.SIGGRANT),
		"SIGHUP":                        reflect.ValueOf(syscall.SIGHUP),
		"SIGILL":                        reflect.ValueOf(syscall.SIGILL),
		"SIGINT":                        reflect.ValueOf(syscall.SIGINT),
		"SIGIO":                         reflect.ValueOf(syscall.SIGIO),
		"SIGIOINT":                      reflect.ValueOf(syscall.SIGIOINT),
		"SIGIOT":                        reflect.ValueOf(syscall.SIGIOT),
		"SIGKAP":                        reflect.ValueOf(syscall.SIGKAP),
		"SIGKILL":                       reflect.ValueOf(syscall.SIGKILL),
		"SIGLOST":                       reflect.ValueOf(syscall.SIGLOST),
		"SIGMAX":                        reflect.ValueOf(syscall.SIGMAX),
		"SIGMAX32":                      reflect.ValueOf(syscall.SIGMAX32),
		"SIGMAX64":                      reflect.ValueOf(syscall.SIGMAX64),
		"SIGMIGRATE":                    reflect.ValueOf(syscall.SIGMIGRATE),
		"SIGMSG":                        reflect.ValueOf(syscall.SIGMSG),
		"SIGPIPE":                       reflect.ValueOf(syscall.SIGPIPE),
		"SIGPOLL":                       reflect.ValueOf(syscall.SIGPOLL),
		"SIGPRE":                        reflect.ValueOf(syscall.SIGPRE),
		"SIGPROF":                       reflect.ValueOf(syscall.SIGPROF),
		"SIGPTY":                        reflect.ValueOf(syscall.SIGPTY),
		"SIGPWR":                        reflect.ValueOf(syscall.SIGPWR),
		"SIGQUEUE_MAX":                  reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"SIGQUIT":                       reflect.ValueOf(syscall.SIGQUIT),
		"SIGRECONFIG":                   reflect.ValueOf(syscall.SIGRECONFIG),
		"SIGRETRACT":                    reflect.ValueOf(syscall.SIGRETRACT),
		"SIGSAK":                        reflect.ValueOf(syscall.SIGSAK),
		"SIGSEGV":                       reflect.ValueOf(syscall.SIGSEGV),
		"SIGSOUND":                      reflect.ValueOf(syscall.SIGSOUND),
		"SIGSTOP":                       reflect.ValueOf(syscall.SIGSTOP),
		"SIGSYS":                        reflect.ValueOf(syscall.SIGSYS),
		"SIGSYSERROR":                   reflect.ValueOf(syscall.SIGSYSERROR),
		"SIGTALRM":                      reflect.ValueOf(syscall.SIGTALRM),
		"SIGTERM":                       reflect.ValueOf(syscall.SIGTERM),
		"SIGTRAP":                       reflect.ValueOf(syscall.SIGTRAP),
		"SIGTSTP":                       reflect.ValueOf(syscall.SIGTSTP),
		"SIGTTIN":                       reflect.ValueOf(syscall.SIGTTIN),
		"SIGTTOU":                       reflect.ValueOf(syscall.SIGTTOU),
		"SIGURG":                        reflect.ValueOf(syscall.SIGURG),
		"SIGUSR1":                       reflect.ValueOf(syscall.SIGUSR1),
		"SIGUSR2":                       reflect.ValueOf(syscall.SIGUSR2),
		"SIGVIRT":                       reflect.ValueOf(syscall.SIGVIRT),
		"SIGVTALRM":                     reflect.ValueOf(syscall.SIGVTALRM),
		"SIGWAITING":                    reflect.ValueOf(syscall.SIGWAITING),
		"SIGWINCH":                      reflect.ValueOf(syscall.SIGWINCH),
		"SIGXCPU":                       reflect.ValueOf(syscall.SIGXCPU),
		"SIGXFSZ":                       reflect.ValueOf(syscall.SIGXFSZ),
		"SIOCADDIFVIPA":                 reflect.ValueOf(constant.MakeFromLiteral("536897858", token.INT, 0)),
		"SIOCADDMTU":                    reflect.ValueOf(constant.MakeFromLiteral("-2147194512", token.INT, 0)),
		"SIOCADDMULTI":                  reflect.ValueOf(constant.MakeFromLiteral("-2145359567", token.INT, 0)),
		"SIOCADDNETID":                  reflect.ValueOf(constant.MakeFromLiteral("-2144835241", token.INT, 0)),
		"SIOCADDRT":                     reflect.ValueOf(constant.MakeFromLiteral("-2143784438", token.INT, 0)),
		"SIOCAIFADDR":                   reflect.ValueOf(constant.MakeFromLiteral("-2143262438", token.INT, 0)),
		"SIOCATMARK":                    reflect.ValueOf(constant.MakeFromLiteral("1074033415", token.INT, 0)),
		"SIOCDARP":                      reflect.ValueOf(constant.MakeFromLiteral("-2142476000", token.INT, 0)),
		"SIOCDELIFVIPA":                 reflect.ValueOf(constant.MakeFromLiteral("536897859", token.INT, 0)),
		"SIOCDELMTU":                    reflect.ValueOf(constant.MakeFromLiteral("-2147194511", token.INT, 0)),
		"SIOCDELMULTI":                  reflect.ValueOf(constant.MakeFromLiteral("-2145359566", token.INT, 0)),
		"SIOCDELPMTU":                   reflect.ValueOf(constant.MakeFromLiteral("-2144833526", token.INT, 0)),
		"SIOCDELRT":                     reflect.ValueOf(constant.MakeFromLiteral("-2143784437", token.INT, 0)),
		"SIOCDIFADDR":                   reflect.ValueOf(constant.MakeFromLiteral("-2144835303", token.INT, 0)),
		"SIOCDNETOPT":                   reflect.ValueOf(constant.MakeFromLiteral("-1073649280", token.INT, 0)),
		"SIOCDX25XLATE":                 reflect.ValueOf(constant.MakeFromLiteral("-2144835227", token.INT, 0)),
		"SIOCFIFADDR":                   reflect.ValueOf(constant.MakeFromLiteral("-2145359469", token.INT, 0)),
		"SIOCGARP":                      reflect.ValueOf(constant.MakeFromLiteral("-1068734170", token.INT, 0)),
		"SIOCGETMTUS":                   reflect.ValueOf(constant.MakeFromLiteral("536897903", token.INT, 0)),
		"SIOCGETSGCNT":                  reflect.ValueOf(constant.MakeFromLiteral("-1072401100", token.INT, 0)),
		"SIOCGETVIFCNT":                 reflect.ValueOf(constant.MakeFromLiteral("-1072401101", token.INT, 0)),
		"SIOCGHIWAT":                    reflect.ValueOf(constant.MakeFromLiteral("1074033409", token.INT, 0)),
		"SIOCGIFADDR":                   reflect.ValueOf(constant.MakeFromLiteral("-1071093471", token.INT, 0)),
		"SIOCGIFADDRS":                  reflect.ValueOf(constant.MakeFromLiteral("536897932", token.INT, 0)),
		"SIOCGIFBAUDRATE":               reflect.ValueOf(constant.MakeFromLiteral("-1071093395", token.INT, 0)),
		"SIOCGIFBRDADDR":                reflect.ValueOf(constant.MakeFromLiteral("-1071093469", token.INT, 0)),
		"SIOCGIFCONF":                   reflect.ValueOf(constant.MakeFromLiteral("-1072666299", token.INT, 0)),
		"SIOCGIFCONFGLOB":               reflect.ValueOf(constant.MakeFromLiteral("-1072666224", token.INT, 0)),
		"SIOCGIFDSTADDR":                reflect.ValueOf(constant.MakeFromLiteral("-1071093470", token.INT, 0)),
		"SIOCGIFFLAGS":                  reflect.ValueOf(constant.MakeFromLiteral("-1071093487", token.INT, 0)),
		"SIOCGIFGIDLIST":                reflect.ValueOf(constant.MakeFromLiteral("536897896", token.INT, 0)),
		"SIOCGIFHWADDR":                 reflect.ValueOf(constant.MakeFromLiteral("-1068209771", token.INT, 0)),
		"SIOCGIFMETRIC":                 reflect.ValueOf(constant.MakeFromLiteral("-1071093481", token.INT, 0)),
		"SIOCGIFMTU":                    reflect.ValueOf(constant.MakeFromLiteral("-1071093418", token.INT, 0)),
		"SIOCGIFNETMASK":                reflect.ValueOf(constant.MakeFromLiteral("-1071093467", token.INT, 0)),
		"SIOCGIFOPTIONS":                reflect.ValueOf(constant.MakeFromLiteral("-1071093462", token.INT, 0)),
		"SIOCGISNO":                     reflect.ValueOf(constant.MakeFromLiteral("-1071093397", token.INT, 0)),
		"SIOCGLOADF":                    reflect.ValueOf(constant.MakeFromLiteral("-1073452670", token.INT, 0)),
		"SIOCGLOWAT":                    reflect.ValueOf(constant.MakeFromLiteral("1074033411", token.INT, 0)),
		"SIOCGNETOPT":                   reflect.ValueOf(constant.MakeFromLiteral("-1073649317", token.INT, 0)),
		"SIOCGNETOPT1":                  reflect.ValueOf(constant.MakeFromLiteral("-1071617663", token.INT, 0)),
		"SIOCGNMTUS":                    reflect.ValueOf(constant.MakeFromLiteral("536897902", token.INT, 0)),
		"SIOCGPGRP":                     reflect.ValueOf(constant.MakeFromLiteral("1074033417", token.INT, 0)),
		"SIOCGSIZIFCONF":                reflect.ValueOf(constant.MakeFromLiteral("1074030954", token.INT, 0)),
		"SIOCGSRCFILTER":                reflect.ValueOf(constant.MakeFromLiteral("-1072142027", token.INT, 0)),
		"SIOCGTUNEPHASE":                reflect.ValueOf(constant.MakeFromLiteral("-1073452662", token.INT, 0)),
		"SIOCGX25XLATE":                 reflect.ValueOf(constant.MakeFromLiteral("-1071093404", token.INT, 0)),
		"SIOCIFATTACH":                  reflect.ValueOf(constant.MakeFromLiteral("-2145359513", token.INT, 0)),
		"SIOCIFDETACH":                  reflect.ValueOf(constant.MakeFromLiteral("-2145359514", token.INT, 0)),
		"SIOCIFGETPKEY":                 reflect.ValueOf(constant.MakeFromLiteral("-2145359515", token.INT, 0)),
		"SIOCIF_ATM_DARP":               reflect.ValueOf(constant.MakeFromLiteral("-2145359491", token.INT, 0)),
		"SIOCIF_ATM_DUMPARP":            reflect.ValueOf(constant.MakeFromLiteral("-2145359493", token.INT, 0)),
		"SIOCIF_ATM_GARP":               reflect.ValueOf(constant.MakeFromLiteral("-2145359490", token.INT, 0)),
		"SIOCIF_ATM_IDLE":               reflect.ValueOf(constant.MakeFromLiteral("-2145359494", token.INT, 0)),
		"SIOCIF_ATM_SARP":               reflect.ValueOf(constant.MakeFromLiteral("-2145359489", token.INT, 0)),
		"SIOCIF_ATM_SNMPARP":            reflect.ValueOf(constant.MakeFromLiteral("-2145359495", token.INT, 0)),
		"SIOCIF_ATM_SVC":                reflect.ValueOf(constant.MakeFromLiteral("-2145359492", token.INT, 0)),
		"SIOCIF_ATM_UBR":                reflect.ValueOf(constant.MakeFromLiteral("-2145359496", token.INT, 0)),
		"SIOCIF_DEVHEALTH":              reflect.ValueOf(constant.MakeFromLiteral("-2147194476", token.INT, 0)),
		"SIOCIF_IB_ARP_INCOMP":          reflect.ValueOf(constant.MakeFromLiteral("-2145359479", token.INT, 0)),
		"SIOCIF_IB_ARP_TIMER":           reflect.ValueOf(constant.MakeFromLiteral("-2145359480", token.INT, 0)),
		"SIOCIF_IB_CLEAR_PINFO":         reflect.ValueOf(constant.MakeFromLiteral("-1071617647", token.INT, 0)),
		"SIOCIF_IB_DEL_ARP":             reflect.ValueOf(constant.MakeFromLiteral("-2145359487", token.INT, 0)),
		"SIOCIF_IB_DEL_PINFO":           reflect.ValueOf(constant.MakeFromLiteral("-1071617648", token.INT, 0)),
		"SIOCIF_IB_DUMP_ARP":            reflect.ValueOf(constant.MakeFromLiteral("-2145359488", token.INT, 0)),
		"SIOCIF_IB_GET_ARP":             reflect.ValueOf(constant.MakeFromLiteral("-2145359486", token.INT, 0)),
		"SIOCIF_IB_GET_INFO":            reflect.ValueOf(constant.MakeFromLiteral("-1065850485", token.INT, 0)),
		"SIOCIF_IB_GET_STATS":           reflect.ValueOf(constant.MakeFromLiteral("-1065850482", token.INT, 0)),
		"SIOCIF_IB_NOTIFY_ADDR_REM":     reflect.ValueOf(constant.MakeFromLiteral("-1065850474", token.INT, 0)),
		"SIOCIF_IB_RESET_STATS":         reflect.ValueOf(constant.MakeFromLiteral("-1065850481", token.INT, 0)),
		"SIOCIF_IB_RESIZE_CQ":           reflect.ValueOf(constant.MakeFromLiteral("-2145359481", token.INT, 0)),
		"SIOCIF_IB_SET_ARP":             reflect.ValueOf(constant.MakeFromLiteral("-2145359485", token.INT, 0)),
		"SIOCIF_IB_SET_PKEY":            reflect.ValueOf(constant.MakeFromLiteral("-2145359484", token.INT, 0)),
		"SIOCIF_IB_SET_PORT":            reflect.ValueOf(constant.MakeFromLiteral("-2145359483", token.INT, 0)),
		"SIOCIF_IB_SET_QKEY":            reflect.ValueOf(constant.MakeFromLiteral("-2145359478", token.INT, 0)),
		"SIOCIF_IB_SET_QSIZE":           reflect.ValueOf(constant.MakeFromLiteral("-2145359482", token.INT, 0)),
		"SIOCLISTIFVIPA":                reflect.ValueOf(constant.MakeFromLiteral("536897860", token.INT, 0)),
		"SIOCSARP":                      reflect.ValueOf(constant.MakeFromLiteral("-2142476002", token.INT, 0)),
		"SIOCSHIWAT":                    reflect.ValueOf(constant.MakeFromLiteral("18446744071562359552", token.INT, 0)),
		"SIOCSIFADDR":                   reflect.ValueOf(constant.MakeFromLiteral("-2144835316", token.INT, 0)),
		"SIOCSIFADDRORI":                reflect.ValueOf(constant.MakeFromLiteral("-2145097331", token.INT, 0)),
		"SIOCSIFBRDADDR":                reflect.ValueOf(constant.MakeFromLiteral("-2144835309", token.INT, 0)),
		"SIOCSIFDSTADDR":                reflect.ValueOf(constant.MakeFromLiteral("-2144835314", token.INT, 0)),
		"SIOCSIFFLAGS":                  reflect.ValueOf(constant.MakeFromLiteral("-2144835312", token.INT, 0)),
		"SIOCSIFGIDLIST":                reflect.ValueOf(constant.MakeFromLiteral("536897897", token.INT, 0)),
		"SIOCSIFMETRIC":                 reflect.ValueOf(constant.MakeFromLiteral("-2144835304", token.INT, 0)),
		"SIOCSIFMTU":                    reflect.ValueOf(constant.MakeFromLiteral("-2144835240", token.INT, 0)),
		"SIOCSIFNETDUMP":                reflect.ValueOf(constant.MakeFromLiteral("-2144835300", token.INT, 0)),
		"SIOCSIFNETMASK":                reflect.ValueOf(constant.MakeFromLiteral("-2144835306", token.INT, 0)),
		"SIOCSIFOPTIONS":                reflect.ValueOf(constant.MakeFromLiteral("-2144835287", token.INT, 0)),
		"SIOCSIFSUBCHAN":                reflect.ValueOf(constant.MakeFromLiteral("-2144835301", token.INT, 0)),
		"SIOCSISNO":                     reflect.ValueOf(constant.MakeFromLiteral("-2144835220", token.INT, 0)),
		"SIOCSLOADF":                    reflect.ValueOf(constant.MakeFromLiteral("-1073452669", token.INT, 0)),
		"SIOCSLOWAT":                    reflect.ValueOf(constant.MakeFromLiteral("18446744071562359554", token.INT, 0)),
		"SIOCSNETOPT":                   reflect.ValueOf(constant.MakeFromLiteral("-2147391142", token.INT, 0)),
		"SIOCSPGRP":                     reflect.ValueOf(constant.MakeFromLiteral("18446744071562359560", token.INT, 0)),
		"SIOCSX25XLATE":                 reflect.ValueOf(constant.MakeFromLiteral("-2144835229", token.INT, 0)),
		"SOCK_CONN_DGRAM":               reflect.ValueOf(constant.MakeFromLiteral("6", token.INT, 0)),
		"SOCK_DGRAM":                    reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"SOCK_RAW":                      reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"SOCK_RDM":                      reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"SOCK_SEQPACKET":                reflect.ValueOf(constant.MakeFromLiteral("5", token.INT, 0)),
		"SOCK_STREAM":                   reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"SOL_SOCKET":                    reflect.ValueOf(constant.MakeFromLiteral("65535", token.INT, 0)),
		"SOMAXCONN":                     reflect.ValueOf(constant.MakeFromLiteral("1024", token.INT, 0)),
		"SO_ACCEPTCONN":                 reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"SO_AUDIT":                      reflect.ValueOf(constant.MakeFromLiteral("32768", token.INT, 0)),
		"SO_BROADCAST":                  reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"SO_CKSUMRECV":                  reflect.ValueOf(constant.MakeFromLiteral("2048", token.INT, 0)),
		"SO_DEBUG":                      reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"SO_DONTROUTE":                  reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"SO_ERROR":                      reflect.ValueOf(constant.MakeFromLiteral("4103", token.INT, 0)),
		"SO_KEEPALIVE":                  reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"SO_KERNACCEPT":                 reflect.ValueOf(constant.MakeFromLiteral("8192", token.INT, 0)),
		"SO_LINGER":                     reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"SO_NOMULTIPATH":                reflect.ValueOf(constant.MakeFromLiteral("16384", token.INT, 0)),
		"SO_NOREUSEADDR":                reflect.ValueOf(constant.MakeFromLiteral("4096", token.INT, 0)),
		"SO_OOBINLINE":                  reflect.ValueOf(constant.MakeFromLiteral("256", token.INT, 0)),
		"SO_PEERID":                     reflect.ValueOf(constant.MakeFromLiteral("4105", token.INT, 0)),
		"SO_RCVBUF":                     reflect.ValueOf(constant.MakeFromLiteral("4098", token.INT, 0)),
		"SO_RCVLOWAT":                   reflect.ValueOf(constant.MakeFromLiteral("4100", token.INT, 0)),
		"SO_RCVTIMEO":                   reflect.ValueOf(constant.MakeFromLiteral("4102", token.INT, 0)),
		"SO_REUSEADDR":                  reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"SO_REUSEPORT":                  reflect.ValueOf(constant.MakeFromLiteral("512", token.INT, 0)),
		"SO_SNDBUF":                     reflect.ValueOf(constant.MakeFromLiteral("4097", token.INT, 0)),
		"SO_SNDLOWAT":                   reflect.ValueOf(constant.MakeFromLiteral("4099", token.INT, 0)),
		"SO_SNDTIMEO":                   reflect.ValueOf(constant.MakeFromLiteral("4101", token.INT, 0)),
		"SO_TIMESTAMPNS":                reflect.ValueOf(constant.MakeFromLiteral("4106", token.INT, 0)),
		"SO_TYPE":                       reflect.ValueOf(constant.MakeFromLiteral("4104", token.INT, 0)),
		"SO_USELOOPBACK":                reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"SO_USE_IFBUFS":                 reflect.ValueOf(constant.MakeFromLiteral("1024", token.INT, 0)),
		"SYS_EXECVE":                    reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"SYS_FCNTL":                     reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"S_BANDURG":                     reflect.ValueOf(constant.MakeFromLiteral("1024", token.INT, 0)),
		"S_EMODFMT":                     reflect.ValueOf(constant.MakeFromLiteral("1006632960", token.INT, 0)),
		"S_ENFMT":                       reflect.ValueOf(constant.MakeFromLiteral("1024", token.INT, 0)),
		"S_ERROR":                       reflect.ValueOf(constant.MakeFromLiteral("256", token.INT, 0)),
		"S_HANGUP":                      reflect.ValueOf(constant.MakeFromLiteral("512", token.INT, 0)),
		"S_HIPRI":                       reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"S_ICRYPTO":                     reflect.ValueOf(constant.MakeFromLiteral("524288", token.INT, 0)),
		"S_IEXEC":                       reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"S_IFBLK":                       reflect.ValueOf(constant.MakeFromLiteral("24576", token.INT, 0)),
		"S_IFCHR":                       reflect.ValueOf(constant.MakeFromLiteral("8192", token.INT, 0)),
		"S_IFDIR":                       reflect.ValueOf(constant.MakeFromLiteral("16384", token.INT, 0)),
		"S_IFIFO":                       reflect.ValueOf(constant.MakeFromLiteral("4096", token.INT, 0)),
		"S_IFJOURNAL":                   reflect.ValueOf(constant.MakeFromLiteral("65536", token.INT, 0)),
		"S_IFLNK":                       reflect.ValueOf(constant.MakeFromLiteral("40960", token.INT, 0)),
		"S_IFMPX":                       reflect.ValueOf(constant.MakeFromLiteral("8704", token.INT, 0)),
		"S_IFMT":                        reflect.ValueOf(constant.MakeFromLiteral("61440", token.INT, 0)),
		"S_IFPDIR":                      reflect.ValueOf(constant.MakeFromLiteral("67108864", token.INT, 0)),
		"S_IFPSDIR":                     reflect.ValueOf(constant.MakeFromLiteral("134217728", token.INT, 0)),
		"S_IFPSSDIR":                    reflect.ValueOf(constant.MakeFromLiteral("201326592", token.INT, 0)),
		"S_IFREG":                       reflect.ValueOf(constant.MakeFromLiteral("32768", token.INT, 0)),
		"S_IFSOCK":                      reflect.ValueOf(constant.MakeFromLiteral("49152", token.INT, 0)),
		"S_IFSYSEA":                     reflect.ValueOf(constant.MakeFromLiteral("805306368", token.INT, 0)),
		"S_INPUT":                       reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"S_IREAD":                       reflect.ValueOf(constant.MakeFromLiteral("256", token.INT, 0)),
		"S_IRGRP":                       reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"S_IROTH":                       reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"S_IRUSR":                       reflect.ValueOf(constant.MakeFromLiteral("256", token.INT, 0)),
		"S_IRWXG":                       reflect.ValueOf(constant.MakeFromLiteral("56", token.INT, 0)),
		"S_IRWXO":                       reflect.ValueOf(constant.MakeFromLiteral("7", token.INT, 0)),
		"S_IRWXU":                       reflect.ValueOf(constant.MakeFromLiteral("448", token.INT, 0)),
		"S_ISGID":                       reflect.ValueOf(constant.MakeFromLiteral("1024", token.INT, 0)),
		"S_ISUID":                       reflect.ValueOf(constant.MakeFromLiteral("2048", token.INT, 0)),
		"S_ISVTX":                       reflect.ValueOf(constant.MakeFromLiteral("512", token.INT, 0)),
		"S_ITCB":                        reflect.ValueOf(constant.MakeFromLiteral("16777216", token.INT, 0)),
		"S_ITP":                         reflect.ValueOf(constant.MakeFromLiteral("8388608", token.INT, 0)),
		"S_IWGRP":                       reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"S_IWOTH":                       reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"S_IWRITE":                      reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"S_IWUSR":                       reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"S_IXACL":                       reflect.ValueOf(constant.MakeFromLiteral("33554432", token.INT, 0)),
		"S_IXATTR":                      reflect.ValueOf(constant.MakeFromLiteral("262144", token.INT, 0)),
		"S_IXGRP":                       reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"S_IXINTERFACE":                 reflect.ValueOf(constant.MakeFromLiteral("1048576", token.INT, 0)),
		"S_IXMOD":                       reflect.ValueOf(constant.MakeFromLiteral("1073741824", token.INT, 0)),
		"S_IXOTH":                       reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"S_IXUSR":                       reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"S_MSG":                         reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"S_OUTPUT":                      reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"S_RDBAND":                      reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"S_RDNORM":                      reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"S_RESERVED1":                   reflect.ValueOf(constant.MakeFromLiteral("131072", token.INT, 0)),
		"S_RESERVED2":                   reflect.ValueOf(constant.MakeFromLiteral("2097152", token.INT, 0)),
		"S_RESERVED3":                   reflect.ValueOf(constant.MakeFromLiteral("4194304", token.INT, 0)),
		"S_RESERVED4":                   reflect.ValueOf(constant.MakeFromLiteral("2147483648", token.INT, 0)),
		"S_RESFMT1":                     reflect.ValueOf(constant.MakeFromLiteral("268435456", token.INT, 0)),
		"S_RESFMT10":                    reflect.ValueOf(constant.MakeFromLiteral("872415232", token.INT, 0)),
		"S_RESFMT11":                    reflect.ValueOf(constant.MakeFromLiteral("939524096", token.INT, 0)),
		"S_RESFMT12":                    reflect.ValueOf(constant.MakeFromLiteral("1006632960", token.INT, 0)),
		"S_RESFMT2":                     reflect.ValueOf(constant.MakeFromLiteral("335544320", token.INT, 0)),
		"S_RESFMT3":                     reflect.ValueOf(constant.MakeFromLiteral("402653184", token.INT, 0)),
		"S_RESFMT4":                     reflect.ValueOf(constant.MakeFromLiteral("469762048", token.INT, 0)),
		"S_RESFMT5":                     reflect.ValueOf(constant.MakeFromLiteral("536870912", token.INT, 0)),
		"S_RESFMT6":                     reflect.ValueOf(constant.MakeFromLiteral("603979776", token.INT, 0)),
		"S_RESFMT7":                     reflect.ValueOf(constant.MakeFromLiteral("671088640", token.INT, 0)),
		"S_RESFMT8":                     reflect.ValueOf(constant.MakeFromLiteral("738197504", token.INT, 0)),
		"S_WRBAND":                      reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"S_WRNORM":                      reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"Seek":                          reflect.ValueOf(syscall.Seek),
		"Sendfile":                      reflect.ValueOf(syscall.Sendfile),
		"Sendmsg":                       reflect.ValueOf(syscall.Sendmsg),
		"SendmsgN":                      reflect.ValueOf(syscall.SendmsgN),
		"Sendto":                        reflect.ValueOf(syscall.Sendto),
		"SetNonblock":                   reflect.ValueOf(syscall.SetNonblock),
		"Setegid":                       reflect.ValueOf(syscall.Setegid),
		"Setenv":                        reflect.ValueOf(syscall.Setenv),
		"Seteuid":                       reflect.ValueOf(syscall.Seteuid),
		"Setgid":                        reflect.ValueOf(syscall.Setgid),
		"Setgroups":                     reflect.ValueOf(syscall.Setgroups),
		"Setpgid":                       reflect.ValueOf(syscall.Setpgid),
		"Setpriority":                   reflect.ValueOf(syscall.Setpriority),
		"Setregid":                      reflect.ValueOf(syscall.Setregid),
		"Setreuid":                      reflect.ValueOf(syscall.Setreuid),
		"Setrlimit":                     reflect.ValueOf(syscall.Setrlimit),
		"SetsockoptByte":                reflect.ValueOf(syscall.SetsockoptByte),
		"SetsockoptICMPv6Filter":        reflect.ValueOf(syscall.SetsockoptICMPv6Filter),
		"SetsockoptIPMreq":              reflect.ValueOf(syscall.SetsockoptIPMreq),
		"SetsockoptIPv6Mreq":            reflect.ValueOf(syscall.SetsockoptIPv6Mreq),
		"SetsockoptInet4Addr":           reflect.ValueOf(syscall.SetsockoptInet4Addr),
		"SetsockoptInt":                 reflect.ValueOf(syscall.SetsockoptInt),
		"SetsockoptLinger":              reflect.ValueOf(syscall.SetsockoptLinger),
		"SetsockoptString":              reflect.ValueOf(syscall.SetsockoptString),
		"SetsockoptTimeval":             reflect.ValueOf(syscall.SetsockoptTimeval),
		"SizeofCmsghdr":                 reflect.ValueOf(constant.MakeFromLiteral("12", token.INT, 0)),
		"SizeofICMPv6Filter":            reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"SizeofIPMreq":                  reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"SizeofIPv6Mreq":                reflect.ValueOf(constant.MakeFromLiteral("20", token.INT, 0)),
		"SizeofIfMsghdr":                reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"SizeofLinger":                  reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"SizeofMsghdr":                  reflect.ValueOf(constant.MakeFromLiteral("48", token.INT, 0)),
		"SizeofSockaddrAny":             reflect.ValueOf(constant.MakeFromLiteral("1028", token.INT, 0)),
		"SizeofSockaddrDatalink":        reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"SizeofSockaddrInet4":           reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"SizeofSockaddrInet6":           reflect.ValueOf(constant.MakeFromLiteral("28", token.INT, 0)),
		"SizeofSockaddrUnix":            reflect.ValueOf(constant.MakeFromLiteral("1025", token.INT, 0)),
		"SlicePtrFromStrings":           reflect.ValueOf(syscall.SlicePtrFromStrings),
		"Socket":                        reflect.ValueOf(syscall.Socket),
		"SocketDisableIPv6":             reflect.ValueOf(&syscall.SocketDisableIPv6).Elem(),
		"Socketpair":                    reflect.ValueOf(syscall.Socketpair),
		"Stat":                          reflect.ValueOf(syscall.Stat),
		"Statfs":                        reflect.ValueOf(syscall.Statfs),
		"Stderr":                        reflect.ValueOf(&syscall.Stderr).Elem(),
		"Stdin":                         reflect.ValueOf(&syscall.Stdin).Elem(),
		"Stdout":                        reflect.ValueOf(&syscall.Stdout).Elem(),
		"StringBytePtr":                 reflect.ValueOf(syscall.StringBytePtr),
		"StringByteSlice":               reflect.ValueOf(syscall.StringByteSlice),
		"StringSlicePtr":                reflect.ValueOf(syscall.StringSlicePtr),
		"Symlink":                       reflect.ValueOf(syscall.Symlink),
		"TCIFLUSH":                      reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"TCIOFLUSH":                     reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"TCOFLUSH":                      reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"TCP_24DAYS_WORTH_OF_SLOWTICKS": reflect.ValueOf(constant.MakeFromLiteral("4147200", token.INT, 0)),
		"TCP_ACLADD":                    reflect.ValueOf(constant.MakeFromLiteral("35", token.INT, 0)),
		"TCP_ACLBIND":                   reflect.ValueOf(constant.MakeFromLiteral("38", token.INT, 0)),
		"TCP_ACLCLEAR":                  reflect.ValueOf(constant.MakeFromLiteral("34", token.INT, 0)),
		"TCP_ACLDEL":                    reflect.ValueOf(constant.MakeFromLiteral("36", token.INT, 0)),
		"TCP_ACLDENY":                   reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"TCP_ACLFLUSH":                  reflect.ValueOf(constant.MakeFromLiteral("33", token.INT, 0)),
		"TCP_ACLGID":                    reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"TCP_ACLLS":                     reflect.ValueOf(constant.MakeFromLiteral("37", token.INT, 0)),
		"TCP_ACLSUBNET":                 reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"TCP_ACLUID":                    reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"TCP_CWND_DF":                   reflect.ValueOf(constant.MakeFromLiteral("22", token.INT, 0)),
		"TCP_CWND_IF":                   reflect.ValueOf(constant.MakeFromLiteral("21", token.INT, 0)),
		"TCP_DELAY_ACK_FIN":             reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"TCP_DELAY_ACK_SYN":             reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"TCP_FASTNAME":                  reflect.ValueOf(constant.MakeFromLiteral("16844810", token.INT, 0)),
		"TCP_KEEPCNT":                   reflect.ValueOf(constant.MakeFromLiteral("19", token.INT, 0)),
		"TCP_KEEPIDLE":                  reflect.ValueOf(constant.MakeFromLiteral("17", token.INT, 0)),
		"TCP_KEEPINTVL":                 reflect.ValueOf(constant.MakeFromLiteral("18", token.INT, 0)),
		"TCP_LSPRIV":                    reflect.ValueOf(constant.MakeFromLiteral("41", token.INT, 0)),
		"TCP_LUID":                      reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"TCP_MAXBURST":                  reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"TCP_MAXDF":                     reflect.ValueOf(constant.MakeFromLiteral("100", token.INT, 0)),
		"TCP_MAXIF":                     reflect.ValueOf(constant.MakeFromLiteral("100", token.INT, 0)),
		"TCP_MAXSEG":                    reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"TCP_MAXWIN":                    reflect.ValueOf(constant.MakeFromLiteral("65535", token.INT, 0)),
		"TCP_MAXWINDOWSCALE":            reflect.ValueOf(constant.MakeFromLiteral("14", token.INT, 0)),
		"TCP_MAX_SACK":                  reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"TCP_MSS":                       reflect.ValueOf(constant.MakeFromLiteral("1460", token.INT, 0)),
		"TCP_NODELAY":                   reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"TCP_NODELAYACK":                reflect.ValueOf(constant.MakeFromLiteral("20", token.INT, 0)),
		"TCP_NOREDUCE_CWND_EXIT_FRXMT":  reflect.ValueOf(constant.MakeFromLiteral("25", token.INT, 0)),
		"TCP_NOREDUCE_CWND_IN_FRXMT":    reflect.ValueOf(constant.MakeFromLiteral("24", token.INT, 0)),
		"TCP_NOTENTER_SSTART":           reflect.ValueOf(constant.MakeFromLiteral("23", token.INT, 0)),
		"TCP_OPT":                       reflect.ValueOf(constant.MakeFromLiteral("25", token.INT, 0)),
		"TCP_RFC1323":                   reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"TCP_SETPRIV":                   reflect.ValueOf(constant.MakeFromLiteral("39", token.INT, 0)),
		"TCP_STDURG":                    reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"TCP_TIMESTAMP_OPTLEN":          reflect.ValueOf(constant.MakeFromLiteral("12", token.INT, 0)),
		"TCP_UNSETPRIV":                 reflect.ValueOf(constant.MakeFromLiteral("40", token.INT, 0)),
		"TCSAFLUSH":                     reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"TIOCCBRK":                      reflect.ValueOf(constant.MakeFromLiteral("536900730", token.INT, 0)),
		"TIOCCDTR":                      reflect.ValueOf(constant.MakeFromLiteral("536900728", token.INT, 0)),
		"TIOCCONS":                      reflect.ValueOf(constant.MakeFromLiteral("18446744071562359906", token.INT, 0)),
		"TIOCEXCL":                      reflect.ValueOf(constant.MakeFromLiteral("536900621", token.INT, 0)),
		"TIOCFLUSH":                     reflect.ValueOf(constant.MakeFromLiteral("18446744071562359824", token.INT, 0)),
		"TIOCGETC":                      reflect.ValueOf(constant.MakeFromLiteral("1074164754", token.INT, 0)),
		"TIOCGETD":                      reflect.ValueOf(constant.MakeFromLiteral("1074033664", token.INT, 0)),
		"TIOCGETP":                      reflect.ValueOf(constant.MakeFromLiteral("1074164744", token.INT, 0)),
		"TIOCGLTC":                      reflect.ValueOf(constant.MakeFromLiteral("1074164852", token.INT, 0)),
		"TIOCGPGRP":                     reflect.ValueOf(constant.MakeFromLiteral("1074033783", token.INT, 0)),
		"TIOCGSID":                      reflect.ValueOf(constant.MakeFromLiteral("1074033736", token.INT, 0)),
		"TIOCGSIZE":                     reflect.ValueOf(constant.MakeFromLiteral("1074295912", token.INT, 0)),
		"TIOCGWINSZ":                    reflect.ValueOf(constant.MakeFromLiteral("1074295912", token.INT, 0)),
		"TIOCHPCL":                      reflect.ValueOf(constant.MakeFromLiteral("536900610", token.INT, 0)),
		"TIOCLBIC":                      reflect.ValueOf(constant.MakeFromLiteral("18446744071562359934", token.INT, 0)),
		"TIOCLBIS":                      reflect.ValueOf(constant.MakeFromLiteral("18446744071562359935", token.INT, 0)),
		"TIOCLGET":                      reflect.ValueOf(constant.MakeFromLiteral("1074033788", token.INT, 0)),
		"TIOCLSET":                      reflect.ValueOf(constant.MakeFromLiteral("18446744071562359933", token.INT, 0)),
		"TIOCMBIC":                      reflect.ValueOf(constant.MakeFromLiteral("18446744071562359915", token.INT, 0)),
		"TIOCMBIS":                      reflect.ValueOf(constant.MakeFromLiteral("18446744071562359916", token.INT, 0)),
		"TIOCMGET":                      reflect.ValueOf(constant.MakeFromLiteral("1074033770", token.INT, 0)),
		"TIOCMIWAIT":                    reflect.ValueOf(constant.MakeFromLiteral("18446744071562359908", token.INT, 0)),
		"TIOCMODG":                      reflect.ValueOf(constant.MakeFromLiteral("1074033667", token.INT, 0)),
		"TIOCMODS":                      reflect.ValueOf(constant.MakeFromLiteral("18446744071562359812", token.INT, 0)),
		"TIOCMSET":                      reflect.ValueOf(constant.MakeFromLiteral("18446744071562359917", token.INT, 0)),
		"TIOCM_CAR":                     reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"TIOCM_CD":                      reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"TIOCM_CTS":                     reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"TIOCM_DSR":                     reflect.ValueOf(constant.MakeFromLiteral("256", token.INT, 0)),
		"TIOCM_DTR":                     reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"TIOCM_LE":                      reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"TIOCM_RI":                      reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"TIOCM_RNG":                     reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"TIOCM_RTS":                     reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"TIOCM_SR":                      reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"TIOCM_ST":                      reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"TIOCNOTTY":                     reflect.ValueOf(constant.MakeFromLiteral("536900721", token.INT, 0)),
		"TIOCNXCL":                      reflect.ValueOf(constant.MakeFromLiteral("536900622", token.INT, 0)),
		"TIOCOUTQ":                      reflect.ValueOf(constant.MakeFromLiteral("1074033779", token.INT, 0)),
		"TIOCPKT":                       reflect.ValueOf(constant.MakeFromLiteral("18446744071562359920", token.INT, 0)),
		"TIOCPKT_DATA":                  reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"TIOCPKT_DOSTOP":                reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"TIOCPKT_FLUSHREAD":             reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"TIOCPKT_FLUSHWRITE":            reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"TIOCPKT_NOSTOP":                reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"TIOCPKT_START":                 reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"TIOCPKT_STOP":                  reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"TIOCREMOTE":                    reflect.ValueOf(constant.MakeFromLiteral("18446744071562359913", token.INT, 0)),
		"TIOCSBRK":                      reflect.ValueOf(constant.MakeFromLiteral("536900731", token.INT, 0)),
		"TIOCSCTTY":                     reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"TIOCSDTR":                      reflect.ValueOf(constant.MakeFromLiteral("536900729", token.INT, 0)),
		"TIOCSETC":                      reflect.ValueOf(constant.MakeFromLiteral("18446744071562490897", token.INT, 0)),
		"TIOCSETD":                      reflect.ValueOf(constant.MakeFromLiteral("18446744071562359809", token.INT, 0)),
		"TIOCSETN":                      reflect.ValueOf(constant.MakeFromLiteral("18446744071562490890", token.INT, 0)),
		"TIOCSETP":                      reflect.ValueOf(constant.MakeFromLiteral("18446744071562490889", token.INT, 0)),
		"TIOCSLTC":                      reflect.ValueOf(constant.MakeFromLiteral("18446744071562490997", token.INT, 0)),
		"TIOCSPGRP":                     reflect.ValueOf(constant.MakeFromLiteral("18446744071562359926", token.INT, 0)),
		"TIOCSSIZE":                     reflect.ValueOf(constant.MakeFromLiteral("18446744071562622055", token.INT, 0)),
		"TIOCSTART":                     reflect.ValueOf(constant.MakeFromLiteral("536900718", token.INT, 0)),
		"TIOCSTI":                       reflect.ValueOf(constant.MakeFromLiteral("18446744071562163314", token.INT, 0)),
		"TIOCSTOP":                      reflect.ValueOf(constant.MakeFromLiteral("536900719", token.INT, 0)),
		"TIOCSWINSZ":                    reflect.ValueOf(constant.MakeFromLiteral("18446744071562622055", token.INT, 0)),
		"TIOCUCNTL":                     reflect.ValueOf(constant.MakeFromLiteral("18446744071562359910", token.INT, 0)),
		"TOSTOP":                        reflect.ValueOf(constant.MakeFromLiteral("65536", token.INT, 0)),
		"TimespecToNsec":                reflect.ValueOf(syscall.TimespecToNsec),
		"TimevalToNsec":                 reflect.ValueOf(syscall.TimevalToNsec),
		"Truncate":                      reflect.ValueOf(syscall.Truncate),
		"Umask":                         reflect.ValueOf(syscall.Umask),
		"Uname":                         reflect.ValueOf(syscall.Uname),
		"UnixRights":                    reflect.ValueOf(syscall.UnixRights),
		"Unlink":                        reflect.ValueOf(syscall.Unlink),
		"Unlinkat":                      reflect.ValueOf(syscall.Unlinkat),
		"Unsetenv":                      reflect.ValueOf(syscall.Unsetenv),
		"Utimes":                        reflect.ValueOf(syscall.Utimes),
		"UtimesNano":                    reflect.ValueOf(syscall.UtimesNano),
		"VDISCRD":                       reflect.ValueOf(constant.MakeFromLiteral("12", token.INT, 0)),
		"VDSUSP":                        reflect.ValueOf(constant.MakeFromLiteral("10", token.INT, 0)),
		"VEOF":                          reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"VEOL":                          reflect.ValueOf(constant.MakeFromLiteral("5", token.INT, 0)),
		"VEOL2":                         reflect.ValueOf(constant.MakeFromLiteral("6", token.INT, 0)),
		"VERASE":                        reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"VINTR":                         reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"VKILL":                         reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"VLNEXT":                        reflect.ValueOf(constant.MakeFromLiteral("14", token.INT, 0)),
		"VMIN":                          reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"VQUIT":                         reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"VREPRINT":                      reflect.ValueOf(constant.MakeFromLiteral("11", token.INT, 0)),
		"VSTART":                        reflect.ValueOf(constant.MakeFromLiteral("7", token.INT, 0)),
		"VSTOP":                         reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"VSTRT":                         reflect.ValueOf(constant.MakeFromLiteral("7", token.INT, 0)),
		"VSUSP":                         reflect.ValueOf(constant.MakeFromLiteral("9", token.INT, 0)),
		"VT0":                           reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"VT1":                           reflect.ValueOf(constant.MakeFromLiteral("32768", token.INT, 0)),
		"VTDELAY":                       reflect.ValueOf(constant.MakeFromLiteral("8192", token.INT, 0)),
		"VTDLY":                         reflect.ValueOf(constant.MakeFromLiteral("32768", token.INT, 0)),
		"VTIME":                         reflect.ValueOf(constant.MakeFromLiteral("5", token.INT, 0)),
		"VWERSE":                        reflect.ValueOf(constant.MakeFromLiteral("13", token.INT, 0)),
		"WPARSTART":                     reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"WPARSTOP":                      reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"WPARTTYNAME":                   reflect.ValueOf(constant.MakeFromLiteral("\"Global\"", token.STRING, 0)),
		"Wait4":                         reflect.ValueOf(syscall.Wait4),
		"Write":                         reflect.ValueOf(syscall.Write),

		// type definitions
		"Cmsghdr":              reflect.ValueOf((*syscall.Cmsghdr)(nil)),
		"Conn":                 reflect.ValueOf((*syscall.Conn)(nil)),
		"Credential":           reflect.ValueOf((*syscall.Credential)(nil)),
		"Dirent":               reflect.ValueOf((*syscall.Dirent)(nil)),
		"Errno":                reflect.ValueOf((*syscall.Errno)(nil)),
		"Flock_t":              reflect.ValueOf((*syscall.Flock_t)(nil)),
		"Fsid64_t":             reflect.ValueOf((*syscall.Fsid64_t)(nil)),
		"ICMPv6Filter":         reflect.ValueOf((*syscall.ICMPv6Filter)(nil)),
		"IPMreq":               reflect.ValueOf((*syscall.IPMreq)(nil)),
		"IPv6Mreq":             reflect.ValueOf((*syscall.IPv6Mreq)(nil)),
		"IfMsgHdr":             reflect.ValueOf((*syscall.IfMsgHdr)(nil)),
		"Iovec":                reflect.ValueOf((*syscall.Iovec)(nil)),
		"Linger":               reflect.ValueOf((*syscall.Linger)(nil)),
		"Msghdr":               reflect.ValueOf((*syscall.Msghdr)(nil)),
		"ProcAttr":             reflect.ValueOf((*syscall.ProcAttr)(nil)),
		"RawConn":              reflect.ValueOf((*syscall.RawConn)(nil)),
		"RawSockaddr":          reflect.ValueOf((*syscall.RawSockaddr)(nil)),
		"RawSockaddrAny":       reflect.ValueOf((*syscall.RawSockaddrAny)(nil)),
		"RawSockaddrDatalink":  reflect.ValueOf((*syscall.RawSockaddrDatalink)(nil)),
		"RawSockaddrInet4":     reflect.ValueOf((*syscall.RawSockaddrInet4)(nil)),
		"RawSockaddrInet6":     reflect.ValueOf((*syscall.RawSockaddrInet6)(nil)),
		"RawSockaddrUnix":      reflect.ValueOf((*syscall.RawSockaddrUnix)(nil)),
		"Rlimit":               reflect.ValueOf((*syscall.Rlimit)(nil)),
		"Rusage":               reflect.ValueOf((*syscall.Rusage)(nil)),
		"Signal":               reflect.ValueOf((*syscall.Signal)(nil)),
		"Sockaddr":             reflect.ValueOf((*syscall.Sockaddr)(nil)),
		"SockaddrDatalink":     reflect.ValueOf((*syscall.SockaddrDatalink)(nil)),
		"SockaddrInet4":        reflect.ValueOf((*syscall.SockaddrInet4)(nil)),
		"SockaddrInet6":        reflect.ValueOf((*syscall.SockaddrInet6)(nil)),
		"SockaddrUnix":         reflect.ValueOf((*syscall.SockaddrUnix)(nil)),
		"SocketControlMessage": reflect.ValueOf((*syscall.SocketControlMessage)(nil)),
		"StTimespec_t":         reflect.ValueOf((*syscall.StTimespec_t)(nil)),
		"Stat_t":               reflect.ValueOf((*syscall.Stat_t)(nil)),
		"Statfs_t":             reflect.ValueOf((*syscall.Statfs_t)(nil)),
		"SysProcAttr":          reflect.ValueOf((*syscall.SysProcAttr)(nil)),
		"Termios":              reflect.ValueOf((*syscall.Termios)(nil)),
		"Timespec":             reflect.ValueOf((*syscall.Timespec)(nil)),
		"Timeval":              reflect.ValueOf((*syscall.Timeval)(nil)),
		"Timeval32":            reflect.ValueOf((*syscall.Timeval32)(nil)),
		"Timezone":             reflect.ValueOf((*syscall.Timezone)(nil)),
		"Utsname":              reflect.ValueOf((*syscall.Utsname)(nil)),
		"WaitStatus":           reflect.ValueOf((*syscall.WaitStatus)(nil)),

		// interface wrapper definitions
		"_Conn":     reflect.ValueOf((*_syscall_Conn)(nil)),
		"_RawConn":  reflect.ValueOf((*_syscall_RawConn)(nil)),
		"_Sockaddr": reflect.ValueOf((*_syscall_Sockaddr)(nil)),
	}
}

// _syscall_Conn is an interface wrapper for Conn type
type _syscall_Conn struct {
	IValue       interface{}
	WSyscallConn func() (syscall.RawConn, error)
}

func (W _syscall_Conn) SyscallConn() (syscall.RawConn, error) { return W.WSyscallConn() }

// _syscall_RawConn is an interface wrapper for RawConn type
type _syscall_RawConn struct {
	IValue   interface{}
	WControl func(f func(fd uintptr)) error
	WRead    func(f func(fd uintptr) (done bool)) error
	WWrite   func(f func(fd uintptr) (done bool)) error
}

func (W _syscall_RawConn) Control(f func(fd uintptr)) error           { return W.WControl(f) }
func (W _syscall_RawConn) Read(f func(fd uintptr) (done bool)) error  { return W.WRead(f) }
func (W _syscall_RawConn) Write(f func(fd uintptr) (done bool)) error { return W.WWrite(f) }

// _syscall_Sockaddr is an interface wrapper for Sockaddr type
type _syscall_Sockaddr struct {
	IValue interface{}
}
